# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataYooMoneyWallet(PaymentData):
    """
    Данные для проведения оплаты через ЮMoney.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataYooMoneyWallet, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.YOO_MONEY:
            self.type = PaymentMethodType.YOO_MONEY



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.models.confirmation.confirmation import Confirmation


class ConfirmationEmbedded(Confirmation):
    """
    Сценарий, при котором действия, необходимые для подтверждения платежа, будут зависеть от способа оплаты, который пользователь выберет в виджете ЮKassa.
    Подтверждение от пользователя получит ЮKassa — вам необходимо только встроить виджет к себе на страницу.
    """  # noqa: E501

    __confirmation_token = None
    """Токен для инициализации платежного %[виджета ЮKassa](/developers/payment-acceptance/integration-scenarios/widget/basics). """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ConfirmationEmbedded, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ConfirmationType.EMBEDDED:
            self.type = ConfirmationType.EMBEDDED

    @property
    def confirmation_token(self):
        """
        Возвращает confirmation_token модели ConfirmationEmbedded.

        :return: confirmation_token модели ConfirmationEmbedded.
        :rtype: str
        """
        return self.__confirmation_token

    @confirmation_token.setter
    def confirmation_token(self, value):
        """
        Устанавливает confirmation_token модели ConfirmationEmbedded.

        :param value: confirmation_token модели ConfirmationEmbedded.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__confirmation_token = cast_value



# -*- coding: utf-8 -*-


class Currency(object):
    """
    Трехбуквенный код валюты в формате [ISO-4217](https://www.iso.org/iso-4217-currency-codes.html).
    """  # noqa: E501

    """
    Список допустимых значений
    """
    RUB = "RUB"
    """Российский рубль"""
    USD = "USD"
    """Доллар США"""
    EUR = "EUR"
    """Евро"""
    BYN = "BYN"
    """Белорусский рубль"""
    CNY = "CNY"
    """Китайская йена"""
    KZT = "KZT"
    """Казахский тенге"""
    UAH = "UAH"
    """Украинская гривна"""
    UZS = "UZS"
    """Узбекский сум"""
    TRY = "TRY"
    """Турецкая лира"""
    INR = "INR"
    """Индийская рупия"""
    MDL = "MDL"
    """Молдавский лей"""
    AZN = "AZN"
    """Азербайджанский манат"""
    AMD = "AMD"
    """Армянский драм"""



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class ElectronicCertificateRefundArticle(BaseObject):
    """Товарная позиция в корзине возврата при возврате на электронный сертификат."""  # noqa: E501

    __article_number = None
    """Порядковый номер товара в корзине возврата. От 1 до 999 включительно."""

    __payment_article_number = None
    """Порядковый номер товара в одобренной корзине покупки (article_number в [объекте платежа](https://yookassa.ru/developers/api#payment_object)). От 1 до 999 включительно."""

    __tru_code = None
    """Код ТРУ. 30 символов, две группы цифр, разделенные точкой. Формат: ~`NNNNNNNNN.NNNNNNNNNYYYYMMMMZZZ`, где ~`NNNNNNNNN.NNNNNNNNN` — код вида ТРУ по [Перечню ТРУ](https://esnsi.gosuslugi.ru/classifiers/10616/data?pg=1&p=1), ~`YYYY` — код производителя, ~`MMMM` — код модели, ~`ZZZ` — код страны производителя. Пример: ~`329921120.06001010200080001643`  [Как сформировать код ТРУ](https://yookassa.ru/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/basics#payments-preparations-tru-code) """  # noqa: E501

    __quantity = None
    """Количество возвращаемых единиц товара. Формат: целое положительное число. """  # noqa: E501

    @property
    def article_number(self):
        """Возвращает article_number модели ElectronicCertificateRefundArticle.

        :return: article_number модели ElectronicCertificateRefundArticle.
        :rtype: int
        """
        return self.__article_number

    @article_number.setter
    def article_number(self, value):
        """Устанавливает article_number модели ElectronicCertificateRefundArticle.

        :param value: article_number модели ElectronicCertificateRefundArticle.
        :type value: int
        """
        self.__article_number = value

    @property
    def payment_article_number(self):
        """Возвращает payment_article_number модели ElectronicCertificateRefundArticle.

        :return: payment_article_number модели ElectronicCertificateRefundArticle.
        :rtype: int
        """
        return self.__payment_article_number

    @payment_article_number.setter
    def payment_article_number(self, value):
        """Устанавливает payment_article_number модели ElectronicCertificateRefundArticle.

        :param value: payment_article_number модели ElectronicCertificateRefundArticle.
        :type value: int
        """
        self.__payment_article_number = value

    @property
    def tru_code(self):
        """Возвращает tru_code модели ElectronicCertificateRefundArticle.

        :return: tru_code модели ElectronicCertificateRefundArticle.
        :rtype: str
        """
        return self.__tru_code

    @tru_code.setter
    def tru_code(self, value):
        """Устанавливает tru_code модели ElectronicCertificateRefundArticle.

        :param value: tru_code модели ElectronicCertificateRefundArticle.
        :type value: str
        """
        self.__tru_code = value

    @property
    def quantity(self):
        """Возвращает quantity модели ElectronicCertificateRefundArticle.

        :return: quantity модели ElectronicCertificateRefundArticle.
        :rtype: int
        """
        return self.__quantity

    @quantity.setter
    def quantity(self, value):
        """Устанавливает quantity модели ElectronicCertificateRefundArticle.

        :param value: quantity модели ElectronicCertificateRefundArticle.
        :type value: int
        """
        self.__quantity = value





# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.refund_data.refund_data import ResponseRefundData


class RefundDataUnknown(ResponseRefundData):
    """
    Данные для возврата на неизвестный платежный метод.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(RefundDataUnknown, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.UNKNOWN:
            self.type = PaymentMethodType.UNKNOWN



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount


class RefundSource(BaseObject):
    """
    Данные о том, с какого магазина и какую сумму нужно удержать для проведения возврата. Сейчас в этом параметре можно передать данные только одного магазина.
    """  # noqa: E501

    __account_id = None
    """Идентификатор магазина, для которого вы хотите провести возврат."""  # noqa: E501

    __amount = None
    """Сумма возврата."""  # noqa: E501

    __platform_fee_amount = None
    """Комиссия, которую вы удержали при оплате, и хотите вернуть."""  # noqa: E501

    @property
    def account_id(self):
        """
        Возвращает account_id модели RefundSource.

        :return: account_id модели RefundSource.
        :rtype: str
        """
        return self.__account_id

    @account_id.setter
    def account_id(self, value):
        """
        Устанавливает account_id модели RefundSource.

        :param value: account_id модели RefundSource.
        :type value: str
        """
        self.__account_id = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели RefundSource.

        :return: amount модели RefundSource.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели RefundSource.

        :param value: amount модели RefundSource.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def platform_fee_amount(self):
        """
        Возвращает platform_fee_amount модели RefundSource.

        :return: platform_fee_amount модели RefundSource.
        :rtype: Amount
        """
        return self.__platform_fee_amount

    @platform_fee_amount.setter
    def platform_fee_amount(self, value):
        """
        Устанавливает platform_fee_amount модели RefundSource.

        :param value: platform_fee_amount модели RefundSource.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__platform_fee_amount = Amount(value)
        elif isinstance(value, Amount):
            self.__platform_fee_amount = value
        else:
            raise TypeError('Invalid platform_fee_amount value type')



# -*- coding: utf-8 -*-
from yookassa.domain.models.confirmation.confirmation import Confirmation


class ConfirmationRequest(Confirmation):
    """
    Данные, необходимые для инициирования выбранного сценария подтверждения платежа пользователем.
    Подробнее о [сценариях подтверждения](/developers/payment-acceptance/getting-started/payment-process#user-confirmation).
    """  # noqa: E501

    __locale = None
    """Язык интерфейса, писем и смс, которые будет видеть или получать пользователь""" # noqa: E501

    @property
    def locale(self):
        """
        Возвращает locale модели ConfirmationRequest.

        :return: locale модели ConfirmationRequest.
        :rtype: Locale
        """
        return self.__locale

    @locale.setter
    def locale(self, value):
        """
        Устанавливает locale модели ConfirmationRequest.

        :param value: locale модели ConfirmationRequest.
        :type value: Locale
        """
        self.__locale = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.refund_data.refund_data import ResponseRefundData


class RefundDataSbp(ResponseRefundData):
    """
    Данные для возврата платежа через СБП (НСПК).
    """  # noqa: E501

    __sbp_operation_id = None
    """Идентификатор операции в СБП (НСПК). Пример: ~`1027088AE4CB48CB81287833347A8777`.  Обязательный параметр для возвратов в статусе ~`succeeded`. В остальных случаях может отсутствовать. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(RefundDataSbp, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBP:
            self.type = PaymentMethodType.SBP

    @property
    def sbp_operation_id(self):
        """
        Возвращает sbp_operation_id модели RefundDataSbp.

        :return: sbp_operation_id модели RefundDataSbp.
        :rtype: str
        """
        return self.__sbp_operation_id

    @sbp_operation_id.setter
    def sbp_operation_id(self, value):
        """
        Устанавливает sbp_operation_id модели RefundDataSbp.

        :param value: sbp_operation_id модели RefundDataSbp.
        :type value: str
        """
        self.__sbp_operation_id = value



# coding: utf-8

from yookassa.domain.common import ResponseObject
from yookassa.domain.models import CancellationDetails
from yookassa.domain.models.invoice import PaymentDetails, LineItem, DeliveryMethodType
from yookassa.domain.models.invoice_data.delivery_method_class_map import DeliveryMethodClassMap
from yookassa.domain.models.invoice_data.delivery_method_factory import DeliveryMethodFactory


class InvoiceResponse(ResponseObject):
    """Данные о счете."""  # noqa: E501

    __id = None
    """Идентификатор счета в ЮКасса."""  # noqa: E501

    __status = None
    """Статус счета. Возможные значения: `pending`, `succeeded`, `canceled`."""  # noqa: E501

    __cart = None
    """Корзина заказа — список товаров или услуг, который отобразится на странице счета перед оплатой."""  # noqa: E501

    __delivery_method = None
    """Данные о выбранном способе доставки счета. Присутствует только для счетов в статусе `pending`."""  # noqa: E501

    __payment_details = None
    """Данные о платеже по выставленному счету. Присутствуют, только если платеж успешно [подтвержден пользователем](https://yookassa.ru/developers/payment-acceptance/getting-started/payment-process#user-confirmation)."""  # noqa: E501

    __created_at = None
    """Дата и время создания счета на оплату. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __expires_at = None
    """
    Срок действия счета — дата и время, до которых можно оплатить выставленный счет. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601).
    Пример: `2024-10-18T10:51:18.139Z`
    Присутствует только для счетов в статусе `pending`.
    """  # noqa: E501

    __description = None
    """Описание выставленного счета (не более 128 символов), которое вы увидите в личном кабинете ЮKassa, а пользователь на странице счета. Например: «Счет на оплату по договору 37». """  # noqa: E501

    __cancellation_details = None
    """Комментарий к статусу canceled: кто отменил счет и по какой причине."""

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def id(self):
        """Возвращает id модели InvoiceResponse.

        :return: id модели InvoiceResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """Устанавливает id модели InvoiceResponse.

        :param value: id модели InvoiceResponse.
        :type value: str
        """
        self.__id = value

    @property
    def status(self):
        """Возвращает status модели InvoiceResponse.

        :return: status модели InvoiceResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """Устанавливает status модели InvoiceResponse.

        :param value: status модели InvoiceResponse.
        :type value: str
        """
        self.__status = value

    @property
    def cart(self):
        """Возвращает cart модели InvoiceResponse.

        :return: cart модели InvoiceResponse.
        :rtype: list[LineItem]
        """
        return self.__cart

    @cart.setter
    def cart(self, value):
        """Устанавливает cart модели InvoiceResponse.

        :param value: cart модели InvoiceResponse.
        :type value: list[LineItem]
        """
        if isinstance(value, list):
            cart_array = []
            for cartData in value:
                if isinstance(cartData, dict):
                    cart_array.append(LineItem(cartData))
                elif isinstance(cartData, LineItem):
                    cart_array.append(cartData)
                else:
                    raise TypeError('Invalid cart data type in InvoiceResponse.cart')

            self.__cart = cart_array

    @property
    def delivery_method(self):
        """Возвращает delivery_method модели InvoiceResponse.

        :return: delivery_method модели InvoiceResponse.
        :rtype: InvoiceDeliveryMethod
        """
        return self.__delivery_method

    @delivery_method.setter
    def delivery_method(self, value):
        """Устанавливает delivery_method модели InvoiceResponse.

        :param value: delivery_method модели InvoiceResponse.
        :type value: InvoiceDeliveryMethod
        """
        if isinstance(value, dict) and 'type' in value and value['type'] not in DeliveryMethodClassMap().response:
            value['type'] = DeliveryMethodType.UNKNOWN
        self.__delivery_method = DeliveryMethodFactory().create(value, self.context())

    @property
    def payment_details(self):
        """Возвращает payment_details модели InvoiceResponse.

        :return: payment_details модели InvoiceResponse.
        :rtype: PaymentDetails
        """
        return self.__payment_details

    @payment_details.setter
    def payment_details(self, value):
        """Устанавливает payment_details модели InvoiceResponse.

        :param value: payment_details модели InvoiceResponse.
        :type value: PaymentDetails
        """
        self.__payment_details = PaymentDetails(value)

    @property
    def created_at(self):
        """Возвращает created_at модели InvoiceResponse.

        :return: created_at модели InvoiceResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """Устанавливает created_at модели InvoiceResponse.

        :param value: created_at модели InvoiceResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def expires_at(self):
        """Возвращает expires_at модели InvoiceResponse.

        :return: expires_at модели InvoiceResponse.
        :rtype: datetime
        """
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        """Устанавливает expires_at модели InvoiceResponse.

        :param value: expires_at модели InvoiceResponse.
        :type value: datetime
        """
        self.__expires_at = value

    @property
    def description(self):
        """Возвращает description модели InvoiceResponse.

        :return: description модели InvoiceResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """Устанавливает description модели InvoiceResponse.

        :param value: description модели InvoiceResponse.
        :type value: str
        """
        self.__description = value

    @property
    def cancellation_details(self):
        """Возвращает cancellation_details модели Invoice.

        :return: cancellation_details модели Invoice.
        :rtype: CancellationDetails
        """
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        """Устанавливает cancellation_details модели Invoice.

        :param value: cancellation_details модели Invoice.
        :type value: CancellationDetails
        """
        self.__cancellation_details = CancellationDetails(value)

    @property
    def metadata(self):
        """Возвращает metadata модели InvoiceResponse.

        :return: metadata модели InvoiceResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """Устанавливает metadata модели InvoiceResponse.

        :param value: metadata модели InvoiceResponse.
        :type value: dict[str, str]
        """
        self.__metadata = value



# coding: utf-8

class FiscalizationProvider(object):
    """
    Решение ЮKassa, которое магазин использует для отправки чеков. Возможные значения:  
        * %[Чеки для самозанятых](/developers/payment-acceptance/receipts/self-employed/basics) — `fns` 
        * %[54-ФЗ: Чеки от ЮKassa](/developers/payment-acceptance/receipts/54fz/yoomoney/basics) — `avanpost` 
        * %[54-ФЗ: сторонняя онлайн-касса](/developers/payment-acceptance/receipts/54fz/other-services/basics) (наименование онлайн-кассы) — `a_qsi` (aQsi online), `atol` (АТОЛ Онлайн), `business_ru` (Бизнес.ру), `evotor` (Эвотор), `first_ofd` (Первый ОФД), `kit_invest` (Кит Инвест), `life_pay` (LIFE PAY), `mertrade` (Mertrade), `modul_kassa` (МодульКасса), `rocket` (RocketR), `shtrih_m` (Orange Data). 
    """  # noqa: E501

    """
    Список допустимых значений
    """
    ATOL = "atol"
    """АТОЛ Онлайн"""
    BUSINESS_RU = "business_ru"
    """Бизнес.ру"""
    SHTRIH_M = "shtrih_m"
    """Orange Data"""
    MODUL_KASSA = "modul_kassa"
    """МодульКасса"""
    EVOTOR = "evotor"
    """Эвотор"""
    KIT_INVEST = "kit_invest"
    """Кит Инвест"""
    A_QSI = "a_qsi"
    """aQsi online"""
    FNS = "fns"
    """Чеки для самозанятых"""
    AVANPOST = "avanpost"
    """54-ФЗ: Чеки от ЮKassa"""
    MERTRADE = "mertrade"
    """Mertrade"""
    FIRST_OFD = "first_ofd"
    """Первый ОФД"""
    LIFE_PAY = "life_pay"
    """LIFE PAY"""
    ROCKET = "rocket"
    """RocketR"""



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import ResponsePaymentData


class PaymentDataAlfabank(ResponsePaymentData):
    """
    Оплата через Альфа-Клик.
    """  # noqa: E501

    __login = None
    """Логин пользователя в Альфа-Клике (привязанный телефон или дополнительный логин)."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataAlfabank, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.ALFABANK:
            self.type = PaymentMethodType.ALFABANK

    @property
    def login(self):
        """
        Возвращает login модели PaymentDataAlfabank.

        :return: login модели PaymentDataAlfabank.
        :rtype: str
        """
        return self.__login

    @login.setter
    def login(self, value):
        """
        Устанавливает login модели PaymentDataAlfabank.

        :param value: login модели PaymentDataAlfabank.
        :type value: str
        """
        self.__login = str(value)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Amount


class ElectronicCertificatePaymentData(BaseObject):
    """Данные от ФЭС НСПК для оплаты по электронному сертификату.  Неоходимо передавать только при [оплате со сбором данных на вашей стороне](/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/merchant-payment-form). """  # noqa: E501

    __amount = None

    __basket_id = None

    @property
    def amount(self):
        """Возвращает amount модели ElectronicCertificatePaymentData.

        :return: amount модели ElectronicCertificatePaymentData.
        :rtype: ElectronicCertificatePaymentDataAmount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """Устанавливает amount модели ElectronicCertificatePaymentData.

        :param value: amount модели ElectronicCertificatePaymentData.
        :type value: ElectronicCertificatePaymentDataAmount
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount data type in ElectronicCertificatePaymentData.amount')

    @property
    def basket_id(self):
        """Возвращает basket_id модели ElectronicCertificatePaymentData.

        :return: basket_id модели ElectronicCertificatePaymentData.
        :rtype: str
        """
        return self.__basket_id

    @basket_id.setter
    def basket_id(self, value):
        """Устанавливает basket_id модели ElectronicCertificatePaymentData.

        :param value: basket_id модели ElectronicCertificatePaymentData.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `basket_id`, must not be `None`")  # noqa: E501
        self.__basket_id = value





# -*- coding: utf-8 -*-
from yookassa.domain.models.self_employed_data.confirmation import SelfEmployedConfirmation, \
    SelfEmployedConfirmationType


class SelfEmployedConfirmationRedirect(SelfEmployedConfirmation):
    """
    Перенаправление пользователя на сайт сервиса Мой налог для выдачи прав ЮMoney.
    """  # noqa: E501

    __confirmation_url = None
    """URL, на который необходимо перенаправить самозанятого для выдачи прав."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(SelfEmployedConfirmationRedirect, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not SelfEmployedConfirmationType.REDIRECT:
            self.type = SelfEmployedConfirmationType.REDIRECT

    @property
    def confirmation_url(self):
        """
        Возвращает confirmation_url модели SelfEmployedConfirmationRedirect.

        :return: confirmation_url модели SelfEmployedConfirmationRedirect.
        :rtype: str
        """
        return self.__confirmation_url

    @confirmation_url.setter
    def confirmation_url(self, value):
        """
        Устанавливает confirmation_url модели SelfEmployedConfirmationRedirect.

        :param value: confirmation_url модели SelfEmployedConfirmationRedirect.
        :type value: str
        """
        self.__confirmation_url = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataApplepay(PaymentData):
    """
    Платежные данные для проведения оплаты при помощи Apple Pay.
    """  # noqa: E501

    __payment_data = None
    """Содержимое поля paymentData объекта PKPaymentToken, закодированное в Base64."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataApplepay, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.APPLEPAY:
            self.type = PaymentMethodType.APPLEPAY

    @property
    def payment_data(self):
        """
        Возвращает payment_data модели PaymentDataApplepay.

        :return: payment_data модели PaymentDataApplepay.
        :rtype: str
        """
        return self.__payment_data

    @payment_data.setter
    def payment_data(self, value):
        """
        Устанавливает payment_data модели PaymentDataApplepay.

        :param value: payment_data модели PaymentDataApplepay.
        :type value: str
        """
        self.__payment_data = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.request import SelfEmployedRequest


class SelfEmployedRequestBuilder(object):
    """
    Конструктор запроса на создание объекта самозанятого.
    """  # noqa: E501

    def __init__(self):
        self.__request = SelfEmployedRequest()

    def set_itn(self, value):
        """
        Устанавливает itn модели SelfEmployedRequestBuilder.

        :param value: itn модели SelfEmployedRequestBuilder.
        :type value: str
        :rtype: SelfEmployedRequestBuilder
        """
        self.__request.itn = value
        return self

    def set_phone(self, value):
        """
        Устанавливает phone модели SelfEmployedRequestBuilder.

        :param value: phone модели SelfEmployedRequestBuilder.
        :type value: str
        :rtype: SelfEmployedRequestBuilder
        """
        self.__request.phone = value
        return self

    def set_description(self, value):
        """
        Устанавливает description модели SelfEmployedRequestBuilder.

        :param value: description модели SelfEmployedRequestBuilder.
        :type value: str
        :rtype: SelfEmployedRequestBuilder
        """
        self.__request.description = value
        return self

    def set_confirmation(self, value):
        """
        Устанавливает confirmation модели SelfEmployedRequestBuilder.

        :param value: confirmation модели SelfEmployedRequestBuilder.
        :type value: SelfEmployedConfirmation
        :rtype: SelfEmployedRequestBuilder
        """
        self.__request.confirmation = value
        return self

    def set_metadata(self, value):
        """
        Устанавливает payment_id модели SelfEmployedRequestBuilder.

        :param value: payment_id модели SelfEmployedRequestBuilder.
        :type value: dict[str, str]
        :rtype: SelfEmployedRequestBuilder
        """
        self.__request.metadata = value
        return self

    def build(self):
        """
        Возвращает request модели SelfEmployedRequestBuilder.

        :return: request модели SelfEmployedRequestBuilder.
        :rtype: SelfEmployedRequest
        """
        return self.__request



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import ResponsePaymentData
from yookassa.domain.models.payment_data.request.payment_data_b2b_sberbank import VatData


class PaymentDataB2bSberbank(ResponsePaymentData):
    """
    Оплата через Сбербанк Бизнес Онлайн.
    """  # noqa: E501

    __payment_purpose = None
    """Назначение платежа (не больше 210 символов)."""  # noqa: E501

    __vat_data = None
    """Данные об НДС."""  # noqa: E501

    __payer_bank_details = None
    """Банковские реквизиты плательщика."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataB2bSberbank, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.B2B_SBERBANK:
            self.type = PaymentMethodType.B2B_SBERBANK

    @property
    def payment_purpose(self):
        """
        Возвращает payment_purpose модели PaymentDataB2bSberbank.

        :return: payment_purpose модели PaymentDataB2bSberbank.
        :rtype: str
        """
        return self.__payment_purpose

    @payment_purpose.setter
    def payment_purpose(self, value):
        """
        Устанавливает payment_purpose модели PaymentDataB2bSberbank.

        :param value: payment_purpose модели PaymentDataB2bSberbank.
        :type value: str
        """
        self.__payment_purpose = str(value)

    @property
    def vat_data(self):
        """
        Возвращает vat_data модели PaymentDataB2bSberbank.

        :return: vat_data модели PaymentDataB2bSberbank.
        :rtype: VatData
        """
        return self.__vat_data

    @vat_data.setter
    def vat_data(self, value):
        """
        Устанавливает vat_data модели PaymentDataB2bSberbank.

        :param value: vat_data модели PaymentDataB2bSberbank.
        :type value: VatData
        """
        if isinstance(value, dict):
            self.__vat_data = VatData(value)
        elif isinstance(value, VatData):
            self.__vat_data = value
        else:
            raise TypeError('Invalid vat_data value type in PaymentDataB2bSberbank')

    @property
    def payer_bank_details(self):
        """
        Возвращает payer_bank_details модели PaymentDataB2bSberbank.

        :return: payer_bank_details модели PaymentDataB2bSberbank.
        :rtype: PayerBankDetails
        """
        return self.__payer_bank_details

    @payer_bank_details.setter
    def payer_bank_details(self, value):
        """
        Устанавливает payer_bank_details модели PaymentDataB2bSberbank.

        :param value: payer_bank_details модели PaymentDataB2bSberbank.
        :type value: PayerBankDetails
        """
        if isinstance(value, dict):
            self.__payer_bank_details = PayerBankDetails(value)
        elif isinstance(value, PayerBankDetails):
            self.__payer_bank_details = value
        else:
            raise TypeError('Invalid payer_bank_details value type in PaymentDataB2bSberbank')


class PayerBankDetails(BaseObject):
    """
    Банковские реквизиты плательщика (юридического лица или ИП).
    """  # noqa: E501

    __full_name = None
    """Полное наименование организации."""  # noqa: E501

    __short_name = None
    """Сокращенное наименование организации."""  # noqa: E501

    __address = None
    """Адрес организации."""  # noqa: E501

    __inn = None
    """Индивидуальный налоговый номер (ИНН) организации."""  # noqa: E501

    __kpp = None
    """Код причины постановки на учет (КПП) организации."""  # noqa: E501

    __bank_name = None
    """Наименование банка организации."""  # noqa: E501

    __bank_branch = None
    """Отделение банка организации."""  # noqa: E501

    __bank_bik = None
    """Банковский идентификационный код (БИК) банка организации."""  # noqa: E501

    __account = None
    """Номер счета организации."""  # noqa: E501

    @property
    def full_name(self):
        """
        Возвращает full_name модели PayerBankDetails.

        :return: full_name модели PayerBankDetails.
        :rtype: str
        """
        return self.__full_name

    @full_name.setter
    def full_name(self, value):
        """
        Устанавливает full_name модели PayerBankDetails.

        :param value: full_name модели PayerBankDetails.
        :type value: str
        """
        self.__full_name = str(value)

    @property
    def short_name(self):
        """
        Возвращает short_name модели PayerBankDetails.

        :return: short_name модели PayerBankDetails.
        :rtype: str
        """
        return self.__short_name

    @short_name.setter
    def short_name(self, value):
        """
        Устанавливает short_name модели PayerBankDetails.

        :param value: short_name модели PayerBankDetails.
        :type value: str
        """
        self.__short_name = str(value)

    @property
    def address(self):
        """
        Возвращает address модели PayerBankDetails.

        :return: address модели PayerBankDetails.
        :rtype: str
        """
        return self.__address

    @address.setter
    def address(self, value):
        """
        Устанавливает address модели PayerBankDetails.

        :param value: address модели PayerBankDetails.
        :type value: str
        """
        self.__address = str(value)

    @property
    def inn(self):
        """
        Возвращает inn модели PayerBankDetails.

        :return: inn модели PayerBankDetails.
        :rtype: str
        """
        return self.__inn

    @inn.setter
    def inn(self, value):
        """
        Устанавливает inn модели PayerBankDetails.

        :param value: inn модели PayerBankDetails.
        :type value: str
        """
        self.__inn = str(value)

    @property
    def kpp(self):
        """
        Возвращает kpp модели PayerBankDetails.

        :return: kpp модели PayerBankDetails.
        :rtype: str
        """
        return self.__inn

    @kpp.setter
    def kpp(self, value):
        """
        Устанавливает kpp модели PayerBankDetails.

        :param value: kpp модели PayerBankDetails.
        :type value: str
        """
        self.__inn = str(value)

    @property
    def bank_name(self):
        """
        Возвращает bank_name модели PayerBankDetails.

        :return: bank_name модели PayerBankDetails.
        :rtype: str
        """
        return self.__bank_name

    @bank_name.setter
    def bank_name(self, value):
        """
        Устанавливает bank_name модели PayerBankDetails.

        :param value: bank_name модели PayerBankDetails.
        :type value: str
        """
        self.__bank_name = str(value)

    @property
    def bank_branch(self):
        """
        Возвращает bank_branch модели PayerBankDetails.

        :return: bank_branch модели PayerBankDetails.
        :rtype: str
        """
        return self.__bank_branch

    @bank_branch.setter
    def bank_branch(self, value):
        """
        Устанавливает bank_branch модели PayerBankDetails.

        :param value: bank_branch модели PayerBankDetails.
        :type value: str
        """
        self.__bank_branch = str(value)

    @property
    def bank_bik(self):
        """
        Возвращает bank_bik модели PayerBankDetails.

        :return: bank_bik модели PayerBankDetails.
        :rtype: str
        """
        return self.__bank_bik

    @bank_bik.setter
    def bank_bik(self, value):
        """
        Устанавливает bank_bik модели PayerBankDetails.

        :param value: bank_bik модели PayerBankDetails.
        :type value: str
        """
        self.__bank_bik = str(value)

    @property
    def account(self):
        """
        Возвращает account модели PayerBankDetails.

        :return: account модели PayerBankDetails.
        :rtype: str
        """
        return self.__account

    @account.setter
    def account(self, value):
        """
        Устанавливает account модели PayerBankDetails.

        :param value: account модели PayerBankDetails.
        :type value: str
        """
        self.__account = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.operational_details import OperationalDetails
from yookassa.domain.models.receipt_data.receipt_customer import ReceiptCustomer
from yookassa.domain.models.receipt_data.receipt_item import ReceiptItem


class Receipt(BaseObject):
    """
    Данные о чеке.
    """  # noqa: E501

    __customer = None
    """Информация о пользователе."""  # noqa: E501

    __items = []
    """Список товаров в заказе. Для чеков по 54-ФЗ можно передать не более 100 товаров, для чеков самозанятых — не более шести. """  # noqa: E501

    __tax_system_code = None
    """Система налогообложения магазина (тег в 54 ФЗ — 1055).  Для сторонних онлайн-касс: обязательный параметр, если вы используете онлайн-кассу Атол Онлайн, обновленную до ФФД 1.2, или у вас несколько систем налогообложения, в остальных случаях не передается. %[Перечень возможных значений](/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#tax-systems)  Для Чеков от ЮKassa: параметр передавать не нужно, ЮKassa его проигнорирует. """  # noqa: E501

    __receipt_industry_details = None
    """Отраслевой реквизит чека (тег в 54 ФЗ — 1261). Можно передавать, если используете Чеки от ЮKassa или онлайн-кассу, обновленную до ФФД 1.2. """  # noqa: E501

    __receipt_operational_details = None
    """Операционный реквизит чека (тег в 54 ФЗ — 1270). Можно передавать, если используете Чеки от ЮKassa или онлайн-кассу, обновленную до ФФД 1.2."""  # noqa: E501

    @property
    def customer(self):
        """
        Возвращает customer модели Receipt.

        :return: customer модели Receipt.
        :rtype: ReceiptDataCustomer
        """
        return self.__customer

    @customer.setter
    def customer(self, value):
        """
        Устанавливает customer модели Receipt.

        :param value: customer модели Receipt.
        :type value: ReceiptDataCustomer
        """
        if isinstance(value, dict):
            self.__customer = ReceiptCustomer(value)
        elif isinstance(value, ReceiptCustomer):
            self.__customer = value
        else:
            raise TypeError('Invalid customer value type')

    @property
    def items(self):
        """
        Возвращает items модели Receipt.

        :return: items модели Receipt.
        :rtype: list[ReceiptDataItem]
        """
        return self.__items

    @items.setter
    def items(self, value):
        """
        Устанавливает items модели Receipt.

        :param value: items модели Receipt.
        :type value: list[ReceiptDataItem]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(ReceiptItem(item))
                elif isinstance(item, ReceiptItem):
                    items.append(item)
                else:
                    raise TypeError('Invalid item type in receipt.items')

            self.__items = items
        elif value is None:
            self.__items = []
        else:
            raise TypeError('Invalid items value type in receipt')

    @property
    def tax_system_code(self):
        """
        Возвращает tax_system_code модели Receipt.

        :return: tax_system_code модели Receipt.
        :rtype: str
        """
        return self.__tax_system_code

    @tax_system_code.setter
    def tax_system_code(self, value):
        """
        Устанавливает tax_system_code модели Receipt.

        :param value: email модели Receipt.
        """
        if isinstance(value, int):
            self.__tax_system_code = value
        else:
            raise TypeError('Invalid tax_system_code value type')

    @property
    def email(self):
        """
        Возвращает email модели Receipt.

        :return: email модели Receipt.
        :rtype: str
        """
        return None

    @email.setter
    def email(self, value):
        """
        Устанавливает email модели Receipt.

        :param value: email модели Receipt.
        :type value: str
        """
        if self.__customer is None:
            self.__customer = ReceiptCustomer()
        self.__customer.email = str(value)

    @property
    def phone(self):
        """
        Возвращает tax_system_code модели Receipt.

        :return: tax_system_code модели Receipt.
        :rtype: str
        """
        return None

    @phone.setter
    def phone(self, value):
        """
        Устанавливает tax_system_code модели Receipt.

        :param value: tax_system_code модели Receipt.
        :type value: str
        """
        if self.__customer is None:
            self.__customer = ReceiptCustomer()
        self.__customer.phone = str(value)

    def has_items(self):
        """
        Возвращает флаг установки items модели Receipt.

        :return: has items модели Receipt.
        :rtype: bool
        """
        return bool(self.items)

    @property
    def receipt_industry_details(self):
        """
        Возвращает receipt_industry_details модели Receipt.

        :return: receipt_industry_details модели Receipt.
        :rtype: list[IndustryDetails]
        """
        return self.__receipt_industry_details

    @receipt_industry_details.setter
    def receipt_industry_details(self, value):
        """
        Устанавливает receipt_industry_details модели Receipt.

        :param value: receipt_industry_details модели Receipt.
        :type value: list[IndustryDetails]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(IndustryDetails(item))
                elif isinstance(item, IndustryDetails):
                    items.append(item)
                else:
                    raise TypeError('Invalid receipt_industry_details data type in ReceiptData.receipt_industry_details')
            self.__receipt_industry_details = items
        else:
            raise TypeError('Invalid receipt_industry_details value type in ReceiptData')

    @property
    def receipt_operational_details(self):
        """
        Возвращает receipt_operational_details модели Receipt.

        :return: receipt_operational_details модели Receipt.
        :rtype: OperationalDetails
        """
        return self.__receipt_operational_details

    @receipt_operational_details.setter
    def receipt_operational_details(self, value):
        """
        Устанавливает receipt_operational_details модели Receipt.

        :param value: receipt_operational_details модели Receipt.
        :type value: OperationalDetails
        """
        if isinstance(value, dict):
            self.__receipt_operational_details = OperationalDetails(value)
        elif isinstance(value, OperationalDetails):
            self.__receipt_operational_details = value
        else:
            raise TypeError('Invalid receipt_operational_details data type in ReceiptData.receipt_operational_details')



# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject
from yookassa.domain.models import Amount


class DealResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе конкретной сделки.
    """  # noqa: E501

    __id = None
    """Идентификатор сделки."""  # noqa: E501

    __type = None
    """Тип сделки. Фиксированное значение: ~`safe_deal` — Безопасная сделка. """  # noqa: E501

    __status = None
    """Статус сделки."""  # noqa: E501

    __balance = None
    """Баланс сделки."""  # noqa: E501

    __payout_balance = None
    """Сумма вознаграждения продавцаю."""  # noqa: E501

    __description = None
    """Описание сделки (не более 128 символов). Используется для фильтрации при [получении списка сделок](/developers/api#get_deals_list). """  # noqa: E501

    __fee_moment = None
    """Момент перечисления вам вознаграждения платформы."""  # noqa: E501

    __created_at = None
    """Время создания сделки. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __expires_at = None
    """Время автоматического закрытия сделки. Если в указанное время сделка всё еще в статусе ~`opened`, ЮKassa вернет деньги покупателю и закроет сделку. По умолчанию время жизни сделки составляет 90 дней. Время указывается  по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __test = None
    """Признак тестовой операции."""  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели DealResponse.

        :return: id модели DealResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели DealResponse.

        :param value: id модели DealResponse.
        :type value: str
        """
        self.__id = value

    @property
    def status(self):
        """
        Возвращает status модели DealResponse.

        :return: status модели DealResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели DealResponse.

        :param value: status модели DealResponse.
        :type value: str
        """
        self.__status = value

    @property
    def balance(self):
        """
        Возвращает balance модели DealResponse.

        :return: balance модели DealResponse.
        :rtype: Amount
        """
        return self.__balance

    @balance.setter
    def balance(self, value):
        """
        Устанавливает balance модели DealResponse.

        :param value: balance модели DealResponse.
        :type value: Amount
        """
        self.__balance = Amount(value)

    @property
    def payout_balance(self):
        """
        Возвращает payout_balance модели DealResponse.

        :return: payout_balance модели DealResponse.
        :rtype: Amount
        """
        return self.__payout_balance

    @payout_balance.setter
    def payout_balance(self, value):
        """
        Устанавливает payout_balance модели DealResponse.

        :param value: payout_balance модели DealResponse.
        :type value: Amount
        """
        self.__payout_balance = Amount(value)

    @property
    def description(self):
        """
        Возвращает description модели DealResponse.

        :return: description модели DealResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели DealResponse.

        :param value: description модели DealResponse.
        :type value: str
        """
        self.__description = value

    @property
    def fee_moment(self):
        """
        Возвращает fee_moment модели DealResponse.

        :return: fee_moment модели DealResponse.
        :rtype: str
        """
        return self.__fee_moment

    @fee_moment.setter
    def fee_moment(self, value):
        """
        Устанавливает fee_moment модели DealResponse.

        :param value: fee_moment модели DealResponse.
        :type value: str
        """
        self.__fee_moment = str(value)

    @property
    def created_at(self):
        """
        Возвращает created_at модели DealResponse.

        :return: created_at модели DealResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели DealResponse.

        :param value: created_at модели DealResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def expires_at(self):
        """
        Возвращает expires_at модели DealResponse.

        :return: expires_at модели DealResponse.
        :rtype: datetime
        """
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        """
        Устанавливает expires_at модели DealResponse.

        :param value: expires_at модели DealResponse.
        :type value: datetime
        """
        self.__expires_at = value

    @property
    def test(self):
        """
        Возвращает test модели DealResponse.

        :return: test модели DealResponse.
        :rtype: bool
        """
        return self.__test

    @test.setter
    def test(self, value):
        """
        Устанавливает test модели DealResponse.

        :param value: test модели DealResponse.
        :type value: bool
        """
        self.__test = bool(value)

    @property
    def metadata(self):
        """
        Возвращает metadata модели DealResponse.

        :return: metadata модели DealResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели DealResponse.

        :param value: metadata модели DealResponse.
        :type value: dict[str, str]
        """
        self.__metadata = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.deal import RefundDealData
from yookassa.domain.models.receipt import Receipt
from yookassa.domain.models.refund_data.refund_data import RequestRefundData
from yookassa.domain.models.refund_data.refund_data_factory import RefundDataFactory
from yookassa.domain.models.refund_data.refund_source import RefundSource


class RefundRequest(RequestObject):
    """
    Объект запроса к API для создания возврата.
    """  # noqa: E501

    __payment_id = None
    """Идентификатор платежа в ЮKassa."""  # noqa: E501

    __amount = None
    """Сумма возврата."""  # noqa: E501

    __description = None
    """Комментарий к возврату, основание для возврата денег пользователю."""  # noqa: E501

    __receipt = None
    """Чек возврата."""  # noqa: E501

    __sources = []
    """Данные о том, с какого магазина и какую сумму нужно удержать для проведения возврата. Необходимо передавать, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-payments/basics). Сейчас в этом параметре можно передать данные только одного магазина."""  # noqa: E501

    __deal = None
    """Информация о сделке."""  # noqa: E501

    __refund_method_data = None
    """Детали возврата. Зависят от способа оплаты, который использовался при проведении платежа."""

    @property
    def payment_id(self):
        """
        Возвращает payment_id модели RefundRequest.

        :return: payment_id модели RefundRequest.
        :rtype: str
        """
        return self.__payment_id

    @payment_id.setter
    def payment_id(self, value):
        """
        Устанавливает payment_id модели RefundRequest.

        :param value: payment_id модели RefundRequest.
        :type value: str
        """
        cast_value = str(value)
        if len(cast_value) == 36:
            self.__payment_id = cast_value
        else:
            raise ValueError('Invalid payment id value')

    @property
    def amount(self):
        """
        Возвращает amount модели RefundRequest.

        :return: amount модели RefundRequest.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели RefundRequest.

        :param value: amount модели RefundRequest.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def description(self):
        """
        Возвращает description модели RefundRequest.

        :return: description модели RefundRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели RefundRequest.

        :param value: description модели RefundRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value and len(cast_value) < 256:
            self.__description = cast_value
        else:
            raise ValueError('Invalid commend value')

    @property
    def sources(self):
        """
        Возвращает sources модели RefundRequest.

        :return: sources модели RefundRequest.
        :rtype: list[RefundSource]
        """
        return self.__sources

    @sources.setter
    def sources(self, value):
        """
        Устанавливает sources модели RefundRequest.

        :param value: sources модели RefundRequest.
        :type value: list[RefundSource]
        """
        if isinstance(value, list):
            self.__sources = [RefundSource(item) for item in value]
        elif value is None:
            self.__sources = []
        else:
            raise TypeError('Invalid sources data type in refund_request.sources')

    @property
    def receipt(self):
        """
        Возвращает receipt модели RefundRequest.

        :return: receipt модели RefundRequest.
        :rtype: Receipt
        """
        return self.__receipt

    @receipt.setter
    def receipt(self, value):
        """
        Устанавливает receipt модели RefundRequest.

        :param value: receipt модели RefundRequest.
        :type value: Receipt
        """
        if isinstance(value, dict):
            self.__receipt = Receipt(value)
        elif isinstance(value, Receipt):
            self.__receipt = value
        else:
            raise TypeError('Invalid receipt value type')

    @property
    def deal(self):
        """
        Возвращает deal модели RefundRequest.

        :return: deal модели RefundRequest.
        :rtype: RefundDealData
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели RefundRequest.

        :param value: deal модели RefundRequest.
        :type value: RefundDealData
        """
        if isinstance(value, dict):
            self.__deal = RefundDealData(value)
        elif isinstance(value, RefundDealData):
            self.__deal = value
        else:
            raise TypeError('Invalid deal value type')

    @property
    def refund_method_data(self):
        """Возвращает refund_method_data модели RefundRequest.

        :return: refund_method_data модели RefundRequest.
        :rtype: RequestRefundData
        """
        return self.__refund_method_data

    @refund_method_data.setter
    def refund_method_data(self, value):
        """Устанавливает refund_method_data модели RefundRequest.

        :param value: refund_method_data модели RefundRequest.
        :type value: RequestRefundData
        """
        if isinstance(value, dict):
            self.__refund_method_data = RefundDataFactory().create(value, self.context())
        elif isinstance(value, RequestRefundData):
            self.__refund_method_data = value
        else:
            raise TypeError('Invalid refund_method_data data type in RefundRequest.refund_method_data')

    def validate(self):
        """
        Влидация данных модели RefundRequest.
        """
        if not self.payment_id:
            self.__set_validation_error('Payment id not specified')

        if not self.amount:
            self.__set_validation_error('Amount not specified')

        if self.amount.value <= 0.0:
            self.__set_validation_error('Invalid amount value: ' + str(self.amount.value))

        if self.receipt and self.receipt.has_items():
            email = self.receipt.email
            phone = self.receipt.phone
            if not email and not phone:
                self.__set_validation_error('Both email and phone values are empty in receipt')

            if not self.receipt.tax_system_code and any(not item.vat_code for item in self.receipt.items):
                self.__set_validation_error('Item vat_id and receipt tax_system_id not specified')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели RefundRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject


class WebhookRequest(RequestObject):
    """
    Объект запроса к API на создание вебхука.
    """  # noqa: E501

    __event = None
    """Событие, которое хотите отслеживать."""  # noqa: E501

    __url = None
    """URL, на который ЮKassa будет отправлять уведомления."""  # noqa: E501

    @property
    def event(self):
        """
        Возвращает event модели WebhookRequest.

        :return: event модели WebhookRequest.
        :rtype: str
        """
        return self.__event

    @event.setter
    def event(self, value):
        """
        Устанавливает event модели WebhookRequest.

        :param value: event модели WebhookRequest.
        :type value: str
        """
        cast_value = str(value)
        self.__event = cast_value

    @property
    def url(self):
        """
        Возвращает url модели WebhookRequest.

        :return: url модели WebhookRequest.
        :rtype: str
        """
        return self.__url

    @url.setter
    def url(self, value):
        """
        Устанавливает url модели WebhookRequest.

        :param value: url модели WebhookRequest.
        :type value: str
        """
        cast_value = str(value)
        self.__url = cast_value



# -*- coding: utf-8 -*-
from yookassa.domain.request.capture_payment_request import CapturePaymentRequest


class CapturePaymentBuilder(object):
    """
    Конструктор запроса на подтверждение оплаты.
    """  # noqa: E501

    def __init__(self):
        self.__request = CapturePaymentRequest()

    def set_amount(self, value):
        """
        Устанавливает amount модели CapturePaymentRequest.

        :param value: amount модели CapturePaymentRequest.
        :type value: Amount
        :rtype: CapturePaymentBuilder
        """
        self.__request.amount = value
        return self

    def set_receipt(self, value):
        """
        Устанавливает receipt модели CapturePaymentRequest.

        :param value: receipt модели CapturePaymentRequest.
        :type value: Receipt
        :rtype: CapturePaymentBuilder
        """
        self.__request.receipt = value
        return self

    def set_airline(self, value):
        """
        Устанавливает airline модели CapturePaymentRequest.

        :param value: airline модели CapturePaymentRequest.
        :type value: Airline
        :rtype: CapturePaymentBuilder
        """
        self.__request.airline = value
        return self

    def set_transfers(self, value):
        """
        Устанавливает transfers модели CapturePaymentRequest.

        :param value: transfers модели CapturePaymentRequest.
        :type value: list[Transfer]
        :rtype: CapturePaymentBuilder
        """
        self.__request.transfers = value
        return self

    def set_deal(self, value):
        """
        Устанавливает deal модели CapturePaymentRequest.

        :param value: deal модели CapturePaymentRequest.
        :type value: PaymentDealInfo
        :rtype: CapturePaymentBuilder
        """
        self.__request.deal = value
        return self

    def build(self):
        """
        Возвращает request модели CapturePaymentBuilder.

        :return: request модели CapturePaymentBuilder.
        :rtype: CapturePaymentRequest
        """
        return self.__request



# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.deal import PaymentDealInfo
from yookassa.domain.models.payment_data.request.airline import Airline
from yookassa.domain.models.receipt import Receipt
from yookassa.domain.models.transfer import Transfer


class CapturePaymentRequest(RequestObject):
    """
    Объект запроса к API на подтверждение оплаты.
    """  # noqa: E501

    __amount = None
    """Итоговая сумма, которая спишется с пользователя. Для платежей банковской картой или из кошелька ЮMoney можно указать часть исходной суммы, в этом случае остаток вернется пользователю."""  # noqa: E501

    __receipt = None
    """Данные фискального чека 54-ФЗ."""  # noqa: E501

    __airline = None
    """Объект с данными для продажи авиабилетов . Используется только для платежей банковской картой."""  # noqa: E501

    __transfers = []
    """Данные об актуальном распределении денег — сколько и в какой магазин нужно перевести. Необходимо передавать, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-payments/basics) и подтверждаете часть платежа. """  # noqa: E501

    __deal = None
    """Данные о сделке, в составе которой проходит платеж. Необходимо передавать, если вы проводите Безопасную сделку  и подтверждаете часть платежа."""  # noqa: E501

    @property
    def amount(self):
        """
        Возвращает amount модели CapturePaymentRequest.

        :return: amount модели CapturePaymentRequest.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели CapturePaymentRequest.

        :param value: amount модели CapturePaymentRequest.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def receipt(self):
        """
        Возвращает receipt модели CapturePaymentRequest.

        :return: receipt модели CapturePaymentRequest.
        :rtype: Receipt
        """
        return self.__receipt

    @receipt.setter
    def receipt(self, value):
        """
        Устанавливает receipt модели CapturePaymentRequest.

        :param value: receipt модели CapturePaymentRequest.
        :type value: Receipt
        """
        if isinstance(value, dict):
            self.__receipt = Receipt(value)
        elif isinstance(value, Receipt):
            self.__receipt = value
        else:
            raise TypeError('Invalid receipt value type')

    @property
    def airline(self):
        """
        Возвращает airline модели CapturePaymentRequest.

        :return: airline модели CapturePaymentRequest.
        :rtype: Airline
        """
        return self.__airline

    @airline.setter
    def airline(self, value):
        """
        Устанавливает airline модели CapturePaymentRequest.

        :param value: airline модели CapturePaymentRequest.
        :type value: Airline
        """
        if isinstance(value, dict):
            self.__airline = Airline(value)
        elif isinstance(value, Airline):
            self.__airline = value
        else:
            raise TypeError('Invalid airline type')

    @property
    def transfers(self):
        """
        Возвращает transfers модели CapturePaymentRequest.

        :return: transfers модели CapturePaymentRequest.
        :rtype: list[Transfer]
        """
        return self.__transfers

    @transfers.setter
    def transfers(self, value):
        """
        Устанавливает transfers модели CapturePaymentRequest.

        :param value: transfers модели CapturePaymentRequest.
        :type value: list[Transfer]
        """
        if isinstance(value, list):
            self.__transfers = [Transfer(item) for item in value]
        elif value is None:
            self.__transfers = []
        else:
            raise TypeError('Invalid transfers data type in capture_payment_request.transfers')

    @property
    def deal(self):
        """
        Возвращает deal модели CapturePaymentRequest.

        :return: deal модели CapturePaymentRequest.
        :rtype: PaymentDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели CapturePaymentRequest.

        :param value: deal модели CapturePaymentRequest.
        :type value: PaymentDealInfo
        """
        if isinstance(value, dict):
            self.__deal = PaymentDealInfo(value)
        elif isinstance(value, PaymentDealInfo):
            self.__deal = value
        else:
            raise TypeError('Invalid deal type')

    def validate(self):
        """
        Влидация данных модели CapturePaymentRequest.
        """
        if self.amount:
            value = self.amount.value
            if not value or value <= 0.0:
                self.__set_validation_error('Invalid amount value: ' + str(value))
        if self.receipt is not None and self.receipt.has_items:
            email = self.receipt.email
            phone = self.receipt.phone
            if not email and not phone:
                self.__set_validation_error('Both email and phone values are empty in receipt')

            if not self.receipt.tax_system_code and any(not item.vat_code for item in self.receipt.items):
                self.__set_validation_error('Item vat_id and receipt tax_system_id not specified')

        if self.deal is not None and len(self.deal.settlements) == 0:
            self.__set_validation_error('Deal.settlements not specified')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели CapturePaymentRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class AuthorizeError(ApiError):
    """
    Ошибка авторизации. Не установлен заголовок.
    """  # noqa: E501
    pass



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class UnauthorizedError(ApiError):
    """
    [Basic Auth] Неверный идентификатор вашего аккаунта в ЮKassa или секретный ключ (имя пользователя и пароль при аутентификации).
    [OAuth 2.0] Невалидный OAuth-токен: он некорректный, устарел или его отозвали. Запросите токен заново.
    """  # noqa: E501
    HTTP_CODE = 401



# -*- coding: utf-8 -*-

from yookassa.domain.common import BaseObject
from yookassa.domain.common.data_context import DataContext


class RequestObject(BaseObject):
    """
    Базовый класс для объектов запроса
    """  # noqa: E501
    @staticmethod
    def context():
        """Возвращает контекст запроса"""
        return DataContext.REQUEST

    def validate(self):
        """Валидация данных запроса"""
        pass



# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.payment_data.request.receiver import ReceiverBankAccount, ReceiverDigitalWallet, \
    ReceiverMobileBalance, ReceiverType


class ReceiverFactory(TypeFactory):
    """
    Фабрика создания объекта Receiver по типу.
    """  # noqa: E501

    def __init__(self):
        super(ReceiverFactory, self).__init__(ReceiverClassMap())


class ReceiverClassMap(DataContext):
    """
    Сопоставление классов Receiver по типу.
    """  # noqa: E501

    def __init__(self):
        super(ReceiverClassMap, self).__init__(('request'))

    @property
    def request(self):
        return {
            ReceiverType.BANK_ACCOUNT: ReceiverBankAccount,
            ReceiverType.DIGITAL_WALLET: ReceiverDigitalWallet,
            ReceiverType.MOBILE_BALANCE: ReceiverMobileBalance,
        }



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class Confirmation(BaseObject):
    """
    Базовый класс генерируемых объектов Confirmation.
    """  # noqa: E501

    __type = None
    """Код сценария подтверждения.""" # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели Confirmation.

        :return: type модели Confirmation.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели Confirmation.

        :param value: type модели Confirmation.
        :type value: str
        """
        self.__type = str(value)



# -*- coding: utf-8 -*-
import uuid

from yookassa.client import ApiClient
from yookassa.domain.common.http_verb import HttpVerb
from yookassa.domain.request import DealRequest
from yookassa.domain.response import DealResponse, DealListResponse


class Deal:
    """
    Класс, представляющий модель Deal.
    """  # noqa: E501

    base_path = '/deals'

    def __init__(self):
        self.client = ApiClient()

    @classmethod
    def find_one(cls, deal_id):
        """
        Возвращает информацию о сделке

        :param deal_id: Уникальный идентификатор сделки
        :return: DealResponse Объект ответа, возвращаемого API при запросе сделки
        """
        instance = cls()
        if not isinstance(deal_id, str) or not deal_id:
            raise ValueError('Invalid payment_id value')

        path = instance.base_path + '/' + deal_id
        response = instance.client.request(HttpVerb.GET, path)
        return DealResponse(response)

    @classmethod
    def create(cls, params, idempotency_key=None):
        """
        Создание сделки

        :param params: Данные передаваемые в API
        :param idempotency_key: Ключ идемпотентности
        :return: DealResponse Объект ответа, возвращаемого API при запросе сделки
        """
        instance = cls()
        path = cls.base_path

        if not idempotency_key:
            idempotency_key = uuid.uuid4()

        headers = {
            'Idempotence-Key': str(idempotency_key)
        }

        if isinstance(params, dict):
            params_object = DealRequest(params)
        elif isinstance(params, DealRequest):
            params_object = params
        else:
            raise TypeError('Invalid params value type')

        response = instance.client.request(HttpVerb.POST, path, None, headers, params_object)
        return DealResponse(response)

    @classmethod
    def list(cls, params=None):
        """
        Возвращает список сделок

        :param params: Данные передаваемые в API
        :return: DealListResponse Объект ответа, возвращаемого API при запросе списка сделок
        """
        if params is None:
            params = {}
        instance = cls()
        path = cls.base_path

        response = instance.client.request(HttpVerb.GET, path, params)
        return DealListResponse(response)



# -*- coding: utf-8 -*-
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.invoice import DeliveryMethodType
# requests
from yookassa.domain.models.invoice_data.request.delivery_method_self import \
    DeliveryMethodSelf as RequestDeliveryMethodSelf
# responses
from yookassa.domain.models.invoice_data.response.delivery_method_self import \
    DeliveryMethodSelf as ResponseDeliveryMethodSelf
from yookassa.domain.models.invoice_data.response.delivery_method_unknown import \
    DeliveryMethodUnknown as ResponseDeliveryMethodUnknown


class DeliveryMethodClassMap(DataContext):
    """
    Сопоставление классов DeliveryMethod по типу.
    """  # noqa: E501

    def __init__(self):
        super(DeliveryMethodClassMap, self).__init__(('request', 'response'))

    @property
    def request(self):
        return {
            DeliveryMethodType.SELF: RequestDeliveryMethodSelf,
        }

    @property
    def response(self):
        return {
            DeliveryMethodType.SELF: ResponseDeliveryMethodSelf,
            DeliveryMethodType.UNKNOWN: ResponseDeliveryMethodUnknown,
        }



# -*- coding: utf-8 -*-


class ConfirmationType:
    """
    Константы, представляющие тип пользовательского процесса подтверждения платежа. Возможные значения:

    * yookassa.domain.common.ConfirmationType.EXTERNAL
    * yookassa.domain.common.ConfirmationType.REDIRECT
    * yookassa.domain.common.ConfirmationType.EMBEDDED
    * yookassa.domain.common.ConfirmationType.QR
    * yookassa.domain.common.ConfirmationType.MOBILE_APPLICATION
    """  # noqa: E501

    """
    Список допустимых значений
    """
    EMBEDDED = 'embedded'
    """Необходимо получить одноразовый код от плательщика для подтверждения платежа"""
    EXTERNAL = 'external'
    """Для подтверждения платежа пользователю необходимо совершить действия во внешней системе (например, ответить на смс)"""
    REDIRECT = 'redirect'
    """Необходимо направить плательщика на страницу партнера"""
    QR = 'qr'
    """Необходимо получить QR-код"""
    MOBILE_APPLICATION = 'mobile_application'
    """Необходимо совершить действия в мобильном приложении"""



# -*- coding: utf-8 -*-
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.common.payment_method_type import PaymentMethodType
# requests
from yookassa.domain.models.refund_data.request.refund_data_electronic_certificate import \
    RefundDataElectronicCertificate as RequestRefundDataElectronicCertificate
#responses
from yookassa.domain.models.refund_data.response.refund_data_electronic_certificate import \
    RefundDataElectronicCertificate as ResponseRefundDataElectronicCertificate
from yookassa.domain.models.refund_data.response.refund_data_sbp import \
    RefundDataSbp as ResponseRefundDataSbp
from yookassa.domain.models.refund_data.response.refund_data_unknown import \
    RefundDataUnknown as ResponseRefundDataUnknown


class RefundDataClassMap(DataContext):
    """
    Сопоставление классов RefundData по типу.
    """  # noqa: E501

    def __init__(self):
        super(RefundDataClassMap, self).__init__(('request', 'response'))

    @property
    def request(self):
        return {
            PaymentMethodType.ELECTRONIC_CERTIFICATE: RequestRefundDataElectronicCertificate,
        }

    @property
    def response(self):
        return {
            PaymentMethodType.SBP: ResponseRefundDataSbp,
            PaymentMethodType.ELECTRONIC_CERTIFICATE: ResponseRefundDataElectronicCertificate,
            PaymentMethodType.UNKNOWN: ResponseRefundDataUnknown,
        }



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class IndustryDetails(BaseObject):
    """
    Данные отраслевого реквизита.
    """  # noqa: E501

    __federal_id = None
    """Идентификатор федерального органа исполнительной власти (тег в 54 ФЗ — 1262)."""  # noqa: E501

    __document_date = None
    """Дата документа основания (тег в 54 ФЗ — 1263). Передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) """  # noqa: E501

    __document_number = None
    """Номер нормативного акта федерального органа исполнительной власти, регламентирующего порядок заполнения реквизита «значение отраслевого реквизита» (тег в 54 ФЗ — 1264). """  # noqa: E501

    __value = None
    """Значение отраслевого реквизита (тег в 54 ФЗ — 1265)."""  # noqa: E501

    @property
    def federal_id(self):
        """
        Возвращает federal_id модели IndustryDetails.

        :return: federal_id модели IndustryDetails.
        :rtype: str
        """
        return self.__federal_id

    @federal_id.setter
    def federal_id(self, value):
        """
        Устанавливает federal_id модели IndustryDetails.

        :param value: federal_id модели IndustryDetails.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `federal_id`, must not be `None`")  # noqa: E501
        if value is not None and not re.search(r'(^00[1-9]{1}$)|(^0[1-6]{1}[0-9]{1}$)|(^07[0-3]{1}$)', value):  # noqa: E501
            raise ValueError(r"Invalid value for `federal_id`, must be a follow pattern or equal to `/(^00[1-9]{1}$)|(^0[1-6]{1}[0-9]{1}$)|(^07[0-3]{1}$)/`")  # noqa: E501
        self.__federal_id = value

    @property
    def document_date(self):
        """
        Возвращает document_date модели IndustryDetails.

        :return: document_date модели IndustryDetails.
        :rtype: date
        """
        return self.__document_date

    @document_date.setter
    def document_date(self, value):
        """
        Устанавливает document_date модели IndustryDetails.

        :param value: document_date модели IndustryDetails.
        :type value: date
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `document_date`, must not be `None`")  # noqa: E501
        self.__document_date = value

    @property
    def document_number(self):
        """
        Возвращает document_number модели IndustryDetails.

        :return: document_number модели IndustryDetails.
        :rtype: str
        """
        return self.__document_number

    @document_number.setter
    def document_number(self, value):
        """
        Устанавливает document_number модели IndustryDetails.

        :param value: document_number модели IndustryDetails.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `document_number`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 32:
            raise ValueError("Invalid value for `document_number`, length must be less than or equal to `32`")  # noqa: E501
        self.__document_number = value

    @property
    def value(self):
        """
        Возвращает value модели IndustryDetails.

        :return: value модели IndustryDetails.
        :rtype: str
        """
        return self.__value

    @value.setter
    def value(self, value):
        """
        Устанавливает value модели IndustryDetails.

        :param value: value модели IndustryDetails.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 256:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `256`")  # noqa: E501
        self.__value = value



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import PaymentMethodType
from yookassa.domain.models.payment_data.electronic_certificate.electronic_certificate import ElectronicCertificate
from yookassa.domain.models.payment_data.electronic_certificate.electronic_certificate_approved_payment_article import \
    ElectronicCertificateApprovedPaymentArticle
from yookassa.domain.models.payment_data.response.payment_data_bank_card import PaymentDataBankCard


class PaymentDataElectronicCertificate(PaymentDataBankCard):
    """Оплата по электронному сертификату."""  # noqa: E501

    __electronic_certificate = None
    """Данные от ФЭС НСПК для оплаты по электронному сертификату. """  # noqa: E501

    __articles = None
    """Одобренная корзина покупки — список товаров, одобренных к оплате по электронному сертификату.  Присутствует только при [оплате на готовой странице ЮKassa](/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/ready-made-payment-form). """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataBankCard, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.ELECTRONIC_CERTIFICATE:
            self.type = PaymentMethodType.ELECTRONIC_CERTIFICATE

    @property
    def electronic_certificate(self):
        """Возвращает electronic_certificate модели PaymentMethodElectronicCertificate.

        :return: electronic_certificate модели PaymentMethodElectronicCertificate.
        :rtype: object
        """
        return self.__electronic_certificate

    @electronic_certificate.setter
    def electronic_certificate(self, value):
        """Устанавливает electronic_certificate модели PaymentMethodElectronicCertificate.

        :param value: electronic_certificate модели PaymentMethodElectronicCertificate.
        :type value: object
        """
        if isinstance(value, dict):
            self.__electronic_certificate = ElectronicCertificate(value)
        elif isinstance(value, ElectronicCertificate):
            self.__electronic_certificate = value
        else:
            raise TypeError(
                'Invalid electronic_certificate data type in PaymentDataElectronicCertificate.electronic_certificate')

    @property
    def articles(self):
        """Возвращает articles модели PaymentMethodElectronicCertificate.

        :return: articles модели PaymentMethodElectronicCertificate.
        :rtype: list[ElectronicCertificateApprovedPaymentArticle]
        """
        return self.__articles

    @articles.setter
    def articles(self, value):
        """Устанавливает articles модели PaymentMethodElectronicCertificate.

        :param value: articles модели PaymentMethodElectronicCertificate.
        :type value: list[ElectronicCertificateApprovedPaymentArticle]
        """
        if isinstance(value, list):
            articles_array = []
            for articlesData in value:
                if isinstance(articlesData, dict):
                    articles_array.append(ElectronicCertificateApprovedPaymentArticle(articlesData))
                elif isinstance(articlesData, ElectronicCertificateApprovedPaymentArticle):
                    articles_array.append(articlesData)
                else:
                    raise TypeError('Invalid articles data type in PaymentDataElectronicCertificate.articles')

            self.__articles = articles_array
        else:
            raise TypeError('Invalid articles value type in PaymentDataElectronicCertificate')





# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class TooManyRequestsError(ApiError):
    """
    Превышен лимит запросов в единицу времени. Попробуйте снизить интенсивность запросов.
    """  # noqa: E501
    HTTP_CODE = 429



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class CreditCard(BaseObject):
    """
    Данные банковской карты.
    """  # noqa: E501

    __first6 = None
    """Первые 6 цифр номера карты (BIN). При оплате картой, %[сохраненной в ЮKassa](/developers/payment-acceptance/scenario-extensions/recurring-payments) и других сервисах, переданный BIN может не соответствовать значениям `last4`, `expiry_year`, `expiry_month`."""  # noqa: E501

    __last4 = None
    """Последние 4 цифры номера карты."""  # noqa: E501

    __expiry_year = None
    """Срок действия, год, YYYY."""  # noqa: E501

    __expiry_month = None
    """Срок действия, месяц, MM."""  # noqa: E501

    __card_type = None
    """Тип банковской карты."""  # noqa: E501

    __card_product = None
    """Карточный продукт платежной системы, с которым ассоциирована банковская карта."""  # noqa: E501

    __issuer_country = None
    """
    Код страны, в которой выпущена карта.
    Передается в формате [ISO-3166 alpha-2](https://www.iso.org/obp/ui/#iso:pub:PUB500001:en).
    Пример: RU.
    """  # noqa: E501

    __issuer_name = None
    """Наименование банка, выпустившего карту."""  # noqa: E501

    __source = None
    """
     Источник данных банковской карты.
    Возможные значения: ~`apple_pay`, ~`google_pay`, ~`mir_pay`.
    Присутствует, если пользователь при оплате выбрал карту, сохраненную в Apple Pay, Google Pay или MirPay.
    """  # noqa: E501

    __id = None
    """Публичный идентификатор карты"""  # noqa: E501

    @property
    def first6(self):
        """
        Возвращает first6 модели CreditCard.

        :return: first6 модели CreditCard.
        :rtype: str
        """
        return self.__first6

    @first6.setter
    def first6(self, value):
        """
        Устанавливает first6 модели CreditCard.

        :param value: first6 модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match('^[0-9]{6}$', cast_value):
            self.__first6 = cast_value
        else:
            raise ValueError('Invalid first6 value')

    @property
    def last4(self):
        """
        Возвращает last4 модели CreditCard.

        :return: last4 модели CreditCard.
        :rtype: str
        """
        return self.__last4

    @last4.setter
    def last4(self, value):
        """
        Устанавливает last4 модели CreditCard.

        :param value: last4 модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^[\d]{4}$', cast_value):
            self.__last4 = cast_value
        else:
            raise ValueError('Invalid last4 value')

    @property
    def expiry_year(self):
        """
        Возвращает expiry_year модели CreditCard.

        :return: expiry_year модели CreditCard.
        :rtype: str
        """
        return self.__expiry_year

    @expiry_year.setter
    def expiry_year(self, value):
        """
        Устанавливает expiry_year модели CreditCard.

        :param value: expiry_year модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^\d\d\d\d$', cast_value) and 2000 < int(cast_value) < 2200:
            self.__expiry_year = cast_value
        else:
            raise ValueError('Invalid card expiry year value')

    @property
    def expiry_month(self):
        """
        Возвращает expiry_month модели CreditCard.

        :return: expiry_month модели CreditCard.
        :rtype: str
        """
        return self.__expiry_month

    @expiry_month.setter
    def expiry_month(self, value):
        """
        Устанавливает expiry_month модели CreditCard.

        :param value: expiry_month модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^\d\d$', cast_value) and 0 < int(cast_value) <= 12:
            self.__expiry_month = cast_value
        else:
            raise ValueError('Invalid card expiry month value')

    @property
    def card_type(self):
        """
        Возвращает card_type модели CreditCard.

        :return: card_type модели CreditCard.
        :rtype: str
        """
        return self.__card_type

    @card_type.setter
    def card_type(self, value):
        """
        Устанавливает card_type модели CreditCard.

        :param value: card_type модели CreditCard.
        :type value: str
        """
        self.__card_type = value

    @property
    def card_product(self):
        """
        Возвращает card_product модели CreditCard.

        :return: card_product модели CreditCard.
        :rtype: BankCardProduct
        """
        return self.__card_product

    @card_product.setter
    def card_product(self, value):
        """
        Устанавливает card_product модели CreditCard.

        :param value: card_product модели CreditCard.
        :type value: BankCardProduct
        """
        if isinstance(value, dict):
            self.__card_product = BankCardProduct(value)
        elif isinstance(value, BankCardProduct):
            self.__card_product = value
        else:
            raise TypeError('Invalid card_product data type in CreditCard.card_product')

    @property
    def issuer_country(self):
        """
        Возвращает issuer_country модели CreditCard.

        :return: issuer_country модели CreditCard.
        :rtype: str
        """
        return self.__issuer_country

    @issuer_country.setter
    def issuer_country(self, value):
        """
        Устанавливает issuer_country модели CreditCard.

        :param value: issuer_country модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if len(cast_value) == 2:
            self.__issuer_country = cast_value
        else:
            raise ValueError('Invalid card issuer country value')

    @property
    def issuer_name(self):
        """
        Возвращает issuer_name модели CreditCard.

        :return: issuer_name модели CreditCard.
        :rtype: str
        """
        return self.__issuer_name

    @issuer_name.setter
    def issuer_name(self, value):
        """
        Устанавливает issuer_name модели CreditCard.

        :param value: issuer_name модели CreditCard.
        :type value: str
        """
        self.__issuer_name = str(value)

    @property
    def source(self):
        """
        Возвращает source модели CreditCard.

        :return: source модели CreditCard.
        :rtype: str
        """
        return self.__source

    @source.setter
    def source(self, value):
        """
        Устанавливает source модели CreditCard.

        :param value: source модели CreditCard.
        :type value: str
        """
        self.__source = str(value)

    @property
    def id(self):
        """
        Возвращает id модели CreditCard.

        :return: id модели CreditCard.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели CreditCard.

        :param value: id модели CreditCard.
        :type value: str
        """
        self.__id = value

class BankCardProduct(BaseObject):
    """Карточный продукт платежной системы, с которым ассоциирована банковская карта.
    Например, карточные продукты платежной системы Мир:
    `Mir Classic`, ~`Mir Classic Credit`, ~`MIR Privilege Plus` и другие. """  # noqa: E501

    __code = None
    """Код карточного продукта. Пример: ~`MCP` """  # noqa: E501

    __name = None
    """Название карточного продукта. Пример: ~`MIR Privilege` """  # noqa: E501

    @property
    def code(self):
        """Возвращает code модели BankCardProduct.

        :return: code модели BankCardProduct.
        :rtype: str
        """
        return self.__code

    @code.setter
    def code(self, value):
        """Устанавливает code модели BankCardProduct.

        :param value: code модели BankCardProduct.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501
        self.__code = value

    @property
    def name(self):
        """Возвращает name модели BankCardProduct.

        :return: name модели BankCardProduct.
        :rtype: str
        """
        return self.__name

    @name.setter
    def name(self, value):
        """Устанавливает name модели BankCardProduct.

        :param value: name модели BankCardProduct.
        :type value: str
        """
        self.__name = value



# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.configuration import Configuration
from yookassa.deal import Deal
from yookassa.invoice import Invoice
from yookassa.payment import Payment
from yookassa.payout import Payout
from yookassa.personal_data import PersonalData
from yookassa.receipt import Receipt
from yookassa.refund import Refund
from yookassa.sbp_banks import SbpBanks
from yookassa.self_employed import SelfEmployed
from yookassa.settings import Settings
from yookassa.webhook import Webhook

__author__ = "YooMoney"
__email__ = 'cms@yoomoney.ru'
__version__ = '3.4.1'



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.models.confirmation.request.confirmation_request import ConfirmationRequest


class ConfirmationRedirect(ConfirmationRequest):
    """
    Сценарий, при котором необходимо отправить плательщика на веб-страницу ЮKassa или партнера для подтверждения платежа.
    """  # noqa: E501

    __return_url = None
    """URL, на который вернется пользователь после подтверждения или отмены платежа на веб-странице. Не более 2048 символов."""  # noqa: E501

    __enforce = None
    """Запрос на проведение платежа с аутентификацией по 3-D Secure. Будет работать, если оплату банковской картой вы по умолчанию принимаете без подтверждения платежа пользователем. В остальных случаях аутентификацией по 3-D Secure будет управлять ЮKassa. Если хотите принимать платежи без дополнительного подтверждения пользователем, напишите вашему менеджеру ЮKassa. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ConfirmationRedirect, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ConfirmationType.REDIRECT:
            self.type = ConfirmationType.REDIRECT

    @property
    def return_url(self):
        """
        Возвращает return_url модели ConfirmationRedirect.

        :return: return_url модели ConfirmationRedirect.
        :rtype: str
        """
        return self.__return_url

    @return_url.setter
    def return_url(self, value):
        """
        Устанавливает return_url модели ConfirmationRedirect.

        :param value: return_url модели ConfirmationRedirect.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__return_url = cast_value
        else:
            raise ValueError('Invalid returnUrl value')

    @property
    def enforce(self):
        """
        Возвращает enforce модели ConfirmationRedirect.

        :return: enforce модели ConfirmationRedirect.
        :rtype: bool
        """
        return self.__enforce

    @enforce.setter
    def enforce(self, value):
        """
        Устанавливает enforce модели ConfirmationRedirect.

        :param value: enforce модели ConfirmationRedirect.
        :type value: bool
        """
        self.__enforce = bool(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common.context import Context


class TypeFactory(object):
    """
    Базовый фабричный класс для объекта, имеющего свойство type.
    """  # noqa: E501
    def __init__(self, context):
        if isinstance(context, Context):
            self.__context = context
        else:
            TypeError('Parameter context should be Context instance')

    def create(self, data, context):
        """
        Создает экземпляр на основе значения и контекста

        :param data: Словарь, содержащий ключ типа
        :param context: Контекст данных
        :return: Экземпляр типизированного объекта
        """
        if isinstance(data, dict) and 'type' in data:
            return self.__get_instance(data, context)

    def __get_instance(self, data, context):
        class_object = self.__get_class_object(data, context)
        return class_object(data)

    def __get_class_object(self, data, context):
        class_object = self.__class_map(context).get(data['type'])
        return class_object

    def __class_map(self, context):
        return self.__context.get_context_data(context)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class SelfEmployedConfirmation(BaseObject):
    """
    Базовый класс генерируемых объектов SelfEmployedConfirmation.
    """  # noqa: E501

    __type = None
    """Код сценария подтверждения."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели SelfEmployedConfirmation.

        :return: type модели SelfEmployedConfirmation.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели SelfEmployedConfirmation.

        :param value: type модели SelfEmployedConfirmation.
        :type value: str
        """
        self.__type = str(value)


class SelfEmployedConfirmationType:
    """
    Код сценария подтверждения пользователем заявки ЮMoney на получение прав для регистрации чеков в сервисе Мой налог. 
    """  # noqa: E501

    """
    Список допустимых значений
    """
    REDIRECT = 'redirect'
    """Необходимо направить плательщика на страницу партнера."""



# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject, PaymentMethodType
from yookassa.domain.models import Amount, CancellationDetails
from yookassa.domain.models.deal import PayoutDealInfo
from yookassa.domain.models.payout_data.payout_destination_factory import PayoutDestinationFactory
from yookassa.domain.models.payout_data.payout_destination_class_map import PayoutDestinationClassMap
from yookassa.domain.models.payout_data.response.income_receipt import IncomeReceipt
from yookassa.domain.models.self_employed import PayoutSelfEmployed


class PayoutResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе конкретной выплаты.
    """  # noqa: E501

    __id = None
    """Идентификатор выплаты."""  # noqa: E501

    __amount = None
    """Сумма выплаты."""  # noqa: E501

    __status = None
    """Текущее состояние выплаты."""  # noqa: E501

    __payout_destination = None
    """Способ проведения выплаты."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов). Например: «Выплата по договору 37». """  # noqa: E501

    __created_at = None
    """Время создания выплаты. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __deal = None
    """Сделка, в рамках которой нужно провести выплату."""  # noqa: E501

    __self_employed = None
    """Данные самозанятого, который получит выплату."""  # noqa: E501

    __receipt = None
    """Данные чека, зарегистрированного в ФНС."""  # noqa: E501

    __cancellation_details = None
    """Комментарий к отмене выплаты."""  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    __test = None
    """Признак тестовой операции."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели PayoutResponse.

        :return: id модели PayoutResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели PayoutResponse.

        :param value: id модели PayoutResponse.
        :type value: str
        """
        self.__id = value

    @property
    def amount(self):
        """
        Возвращает amount модели PayoutResponse.

        :return: amount модели PayoutResponse.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели PayoutResponse.

        :param value: amount модели PayoutResponse.
        :type value: Amount
        """
        self.__amount = Amount(value)

    @property
    def status(self):
        """
        Возвращает status модели PayoutResponse.

        :return: status модели PayoutResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели PayoutResponse.

        :param value: status модели PayoutResponse.
        :type value: str
        """
        self.__status = value

    @property
    def payout_destination(self):
        """
        Возвращает payout_destination модели PayoutResponse.

        :return: payout_destination модели PayoutResponse.
        :rtype: PayoutDestination
        """
        return self.__payout_destination

    @payout_destination.setter
    def payout_destination(self, value):
        """
        Устанавливает payout_destination модели PayoutResponse.

        :param value: payout_destination модели PayoutResponse.
        :type value: PayoutDestination
        """
        if isinstance(value, dict) and 'type' in value and value['type'] not in PayoutDestinationClassMap().response:
            value['type'] = PaymentMethodType.UNKNOWN
        self.__payout_destination = PayoutDestinationFactory().create(value, self.context())

    @property
    def description(self):
        """
        Возвращает description модели PayoutResponse.

        :return: description модели PayoutResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели PayoutResponse.

        :param value: description модели PayoutResponse.
        :type value: str
        """
        self.__description = value

    @property
    def created_at(self):
        """
        Возвращает created_at модели PayoutResponse.

        :return: created_at модели PayoutResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели PayoutResponse.

        :param value: created_at модели PayoutResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def deal(self):
        """
        Возвращает deal модели PayoutResponse.

        :return: deal модели PayoutResponse.
        :rtype: PayoutDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели PayoutResponse.

        :param value: deal модели PayoutResponse.
        :type value: PayoutDealInfo
        """
        self.__deal = PayoutDealInfo(value)

    @property
    def self_employed(self):
        """
        Возвращает self_employed модели PayoutResponse.

        :return: self_employed модели PayoutResponse.
        :rtype: PayoutSelfEmployed
        """
        return self.__self_employed

    @self_employed.setter
    def self_employed(self, value):
        """
        Устанавливает self_employed модели PayoutResponse.

        :param value: self_employed модели PayoutResponse.
        :type value: PayoutSelfEmployed
        """
        self.__self_employed = PayoutSelfEmployed(value)

    @property
    def receipt(self):
        """
        Возвращает receipt модели PayoutResponse.

        :return: receipt модели PayoutResponse.
        :rtype: IncomeReceipt
        """
        return self.__receipt

    @receipt.setter
    def receipt(self, value):
        """
        Устанавливает receipt модели PayoutResponse.

        :param value: receipt модели PayoutResponse.
        :type value: IncomeReceipt
        """
        self.__receipt = IncomeReceipt(value)

    @property
    def cancellation_details(self):
        """
        Возвращает cancellation_details модели PayoutResponse.

        :return: cancellation_details модели PayoutResponse.
        :rtype: CancellationDetails
        """
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        """
        Устанавливает cancellation_details модели PayoutResponse.

        :param value: cancellation_details модели PayoutResponse.
        :type value: CancellationDetails
        """
        self.__cancellation_details = CancellationDetails(value)

    @property
    def metadata(self):
        """
        Возвращает metadata модели PayoutResponse.

        :return: metadata модели PayoutResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели PayoutResponse.

        :param value: metadata модели PayoutResponse.
        :type value: dict[str, str]
        """
        self.__metadata = value

    @property
    def test(self):
        """
        Возвращает test модели PayoutResponse.

        :return: test модели PayoutResponse.
        :rtype: bool
        """
        return self.__test

    @test.setter
    def test(self, value):
        """
        Устанавливает test модели PayoutResponse.

        :param value: test модели PayoutResponse.
        :type value: bool
        """
        self.__test = bool(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.models.confirmation.request.confirmation_request import ConfirmationRequest


class ConfirmationMobileApplication(ConfirmationRequest):
    """
    Сценарий, при котором необходимо совершить действия в мобильном приложении (например, в приложении интернет-банка).
    """  # noqa: E501

    __return_url = None
    """URL или диплинк, на который вернется пользователь после подтверждения или отмены платежа в приложении. Если платеж делали из мобильной версии сайта, передайте URL, если из мобильного приложения — диплинк. Не более 2048 символов."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ConfirmationMobileApplication, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ConfirmationType.MOBILE_APPLICATION:
            self.type = ConfirmationType.MOBILE_APPLICATION

    @property
    def return_url(self):
        """
        Возвращает return_url модели ConfirmationMobileApplication.

        :return: return_url модели ConfirmationMobileApplication.
        :rtype: str
        """
        return self.__return_url

    @return_url.setter
    def return_url(self, value):
        """
        Устанавливает return_url модели ConfirmationMobileApplication.

        :param value: return_url модели ConfirmationMobileApplication.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__return_url = cast_value
        else:
            raise ValueError('Invalid returnUrl value')



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class CreditCard(BaseObject):
    """
    Данные банковской карты (необходимы, если вы собираете данные карты пользователей на своей стороне).
    """  # noqa: E501

    __number = None
    """Номер банковской карты."""  # noqa: E501

    __expiry_year = None
    """Срок действия, год, YYYY."""  # noqa: E501

    __expiry_month = None
    """Срок действия, месяц, MM."""  # noqa: E501

    __csc = None
    """Код CVC2 или CVV2, 3 или 4 символа, печатается на обратной стороне карты."""  # noqa: E501

    __cardholder = None
    """Имя владельца карты."""  # noqa: E501

    @property
    def number(self):
        """
        Возвращает number модели CreditCard.

        :return: number модели CreditCard.
        :rtype: str
        """
        return self.__number

    @number.setter
    def number(self, value):
        """
        Устанавливает number модели CreditCard.

        :param value: number модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^[0-9]{12,19}$', cast_value):
            self.__number = cast_value
        else:
            raise ValueError('Invalid card number value')

    @property
    def expiry_year(self):
        """
        Возвращает expiry_year модели CreditCard.

        :return: expiry_year модели CreditCard.
        :rtype: str
        """
        return self.__expiry_year

    @expiry_year.setter
    def expiry_year(self, value):
        """
        Устанавливает expiry_year модели CreditCard.

        :param value: expiry_year модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^\d\d\d\d$', cast_value) and 2000 < int(cast_value) < 2200:
            self.__expiry_year = cast_value
        else:
            raise ValueError('Invalid card expiry year value')

    @property
    def expiry_month(self):
        """
        Возвращает expiry_month модели CreditCard.

        :return: expiry_month модели CreditCard.
        :rtype: str
        """
        return self.__expiry_month

    @expiry_month.setter
    def expiry_month(self, value):
        """
        Устанавливает expiry_month модели CreditCard.

        :param value: expiry_month модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^\d\d$', cast_value) and 0 < int(cast_value) <= 12:
            self.__expiry_month = cast_value
        else:
            raise ValueError('Invalid card expiry month value')

    @property
    def csc(self):
        """
        Возвращает csc модели CreditCard.

        :return: csc модели CreditCard.
        :rtype: str
        """
        return self.__csc

    @csc.setter
    def csc(self, value):
        """
        Устанавливает csc модели CreditCard.

        :param value: csc модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^\d{3,4}$', cast_value):
            self.__csc = cast_value
        else:
            raise ValueError('Invalid card CSC code value')

    @property
    def cardholder(self):
        """
        Возвращает cardholder модели CreditCard.

        :return: cardholder модели CreditCard.
        :rtype: str
        """
        return self.__cardholder

    @cardholder.setter
    def cardholder(self, value):
        """
        Устанавливает cardholder модели CreditCard.

        :param value: cardholder модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^[a-zA-Z\s]{1,26}$', cast_value):
            self.__cardholder = cast_value
        else:
            raise ValueError('Invalid card holder value')



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class MarkQuantity(BaseObject):
    """
    Дробное количество маркированного товара (тег в 54 ФЗ — 1291). Обязательный параметр, если одновременно выполняются эти условия:
      * вы используете Чеки от ЮKassa или онлайн-кассу, обновленную до ФФД 1.2;
      * товар нужно [маркировать](http://docs.cntd.ru/document/902192509);
      * поле `measure` имеет значение ~`piece`.

    Пример: вы продаете поштучно карандаши. Они поставляются пачками по 100 штук с одним кодом маркировки.
    При продаже одного карандаша нужно в `numerator` передать ~`1`, а в `denominator` — ~`100`.
    """  # noqa: E501

    __numerator = None
    """Числитель — количество продаваемых товаров из одной потребительской упаковки (тег в 54 ФЗ — 1293). Не может превышать `denominator`. """  # noqa: E501

    __denominator = None
    """Знаменатель — общее количество товаров в потребительской упаковке (тег в 54 ФЗ — 1294)."""  # noqa: E501

    @property
    def numerator(self):
        """
        Возвращает numerator модели MarkQuantity.

        :return: numerator модели MarkQuantity.
        :rtype: int
        """
        return self.__numerator

    @numerator.setter
    def numerator(self, value):
        """
        Устанавливает numerator модели MarkQuantity.

        :param value: numerator модели MarkQuantity.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `numerator`, must not be `None`")  # noqa: E501
        if value is not None and value < 1:  # noqa: E501
            raise ValueError("Invalid value for `numerator`, must be a value greater than or equal to `1`")  # noqa: E501
        self.__numerator = value

    @property
    def denominator(self):
        """
        Возвращает denominator модели MarkQuantity.

        :return: denominator модели MarkQuantity.
        :rtype: int
        """
        return self.__denominator

    @denominator.setter
    def denominator(self, value):
        """
        Устанавливает denominator модели MarkQuantity.

        :param value: denominator модели MarkQuantity.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `denominator`, must not be `None`")  # noqa: E501
        if value is not None and value < 1:  # noqa: E501
            raise ValueError("Invalid value for `denominator`, must be a value greater than or equal to `1`")  # noqa: E501
        self.__denominator = value



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class CreditCard(BaseObject):
    """
    Данные банковской карты.
    """  # noqa: E501

    __first6 = None
    """Первые 6 цифр номера карты."""  # noqa: E501

    __last4 = None
    """Последние 4 цифры номера карты."""  # noqa: E501

    __card_type = None
    """Тип банковской карты."""  # noqa: E501

    __issuer_country = None
    """Код страны, в которой выпущена карта. Передается в формате [ISO-3166 alpha-2](https://www.iso.org/obp/ui/#iso:pub:PUB500001:en). Пример: ~`RU`. """  # noqa: E501

    __issuer_name = None
    """Наименование банка, выпустившего карту."""  # noqa: E501

    @property
    def first6(self):
        """
        Возвращает first6 модели CreditCard.

        :return: first6 модели CreditCard.
        :rtype: str
        """
        return self.__first6

    @first6.setter
    def first6(self, value):
        """
        Устанавливает first6 модели CreditCard.

        :param value: first6 модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match('^[0-9]{6}$', cast_value):
            self.__first6 = cast_value
        else:
            raise ValueError('Invalid first6 value')

    @property
    def last4(self):
        """
        Возвращает last4 модели CreditCard.

        :return: last4 модели CreditCard.
        :rtype: str
        """
        return self.__last4

    @last4.setter
    def last4(self, value):
        """
        Устанавливает last4 модели CreditCard.

        :param value: last4 модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r'^[\d]{4}$', cast_value):
            self.__last4 = cast_value
        else:
            raise ValueError('Invalid last4 value')

    @property
    def card_type(self):
        """
        Возвращает card_type модели CreditCard.

        :return: card_type модели CreditCard.
        :rtype: str
        """
        return self.__card_type

    @card_type.setter
    def card_type(self, value):
        """
        Устанавливает card_type модели CreditCard.

        :param value: card_type модели CreditCard.
        :type value: str
        """
        self.__card_type = value

    @property
    def issuer_country(self):
        """
        Возвращает issuer_country модели CreditCard.

        :return: issuer_country модели CreditCard.
        :rtype: str
        """
        return self.__issuer_country

    @issuer_country.setter
    def issuer_country(self, value):
        """
        Устанавливает issuer_country модели CreditCard.

        :param value: issuer_country модели CreditCard.
        :type value: str
        """
        cast_value = str(value)
        if len(cast_value) == 2:
            self.__issuer_country = cast_value
        else:
            raise ValueError('Invalid card issuer country value')

    @property
    def issuer_name(self):
        """
        Возвращает issuer_name модели CreditCard.

        :return: issuer_name модели CreditCard.
        :rtype: str
        """
        return self.__issuer_name

    @issuer_name.setter
    def issuer_name(self, value):
        """
        Устанавливает issuer_name модели CreditCard.

        :param value: issuer_name модели CreditCard.
        :type value: str
        """
        self.__issuer_name = str(value)



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataCash(PaymentData):
    """
    Данные для оплаты наличными в терминалах России или СНГ.
    """  # noqa: E501

    __phone = None
    """Телефон пользователя, на который придет смс с кодом платежа (для внесения наличных). Указывается в формате [ITU-T E.164](https://ru.wikipedia.org/wiki/E.164), например ~`79000000000`. Поле можно оставить пустым: пользователь сможет заполнить его при оплате на стороне ЮKassa. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataCash, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.CASH:
            self.type = PaymentMethodType.CASH

    @property
    def phone(self):
        """
        Возвращает phone модели PaymentDataCash.

        :return: phone модели PaymentDataCash.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели PaymentDataCash.

        :param value: phone модели PaymentDataCash.
        :type value: str
        """
        cast_value = str(value)
        if re.match('^[0-9]{4,15}$', cast_value):
            self.__phone = cast_value
        else:
            raise ValueError('Invalid phone value type')



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class PayoutSelfEmployed(BaseObject):
    """Данные самозанятого, который получит выплату. Необходимо передавать, если вы делаете выплату %[самозанятому](/developers/payouts/scenario-extensions/self-employed). Только для обычных выплат."""  # noqa: E501

    __id = None
    """Идентификатор самозанятого в ЮKassa."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели PayoutSelfEmployed.

        :return: id модели PayoutSelfEmployed.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели PayoutSelfEmployed.

        :param value: id модели PayoutSelfEmployed.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 50:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `50`")  # noqa: E501
        if value is not None and len(value) < 36:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `36`")  # noqa: E501
        self.__id = value


class SelfEmployedStatus(object):
    """
    Статус подключения самозанятого и выдачи ЮMoney прав на регистрацию чеков
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PENDING = "pending"
    """ЮMoney запросили права на регистрацию чеков, но самозанятый еще не ответил на заявку"""
    CONFIRMED = "confirmed"
    """Самозанятый выдал права ЮMoney; вы можете делать выплаты"""
    CANCELED = "canceled"
    """Самозанятый отклонил заявку или отозвал ранее выданные права"""
    UNREGISTERED = "unregistered"
    """Самозанятый с таким ИНН не зарегистрирован в сервисе Мой налог, или пользователь потерял статус самозанятого"""



# -*- coding: utf-8 -*-


class ApiError(Exception):
    """
    Неожиданный код ошибки.
    """  # noqa: E501
    __content = None

    HTTP_CODE = 0

    def __init__(self, *args, **kwargs):
        super(ApiError, self).__init__(*args, **kwargs)
        if args[0] is not None:
            self.__content = dict(args[0])

    @property
    def content(self):
        return self.__content



# -*- coding: utf-8 -*-
from yookassa.domain.common.context import Context


class DataContext(Context):
    """
    Константы, представляющие контекстные типы данных. Возможные значения:

    * yookassa.domain.common.DataContext.REQUEST
    * yookassa.domain.common.DataContext.RESPONSE
    """  # noqa: E501

    """
    Список допустимых значений
    """
    REQUEST = 'request'
    """Запрос"""
    RESPONSE = 'response'
    """Ответ"""



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class Recipient(BaseObject):
    """
    Получатель платежа. Нужен, если вы разделяете потоки платежей в рамках одного аккаунта или создаете платеж в адрес другого аккаунта.
    """  # noqa: E501

    __account_id = None
    """Идентификатор магазина в ЮKassa."""  # noqa: E501

    __gateway_id = None
    """Идентификатор субаккаунта. Используется для разделения потоков платежей в рамках одного аккаунта."""  # noqa: E501

    @property
    def account_id(self):
        """
        Возвращает account_id модели Recipient.

        :return: account_id модели Recipient.
        :rtype: str
        """
        return self.__account_id

    @account_id.setter
    def account_id(self, value):
        """
        Устанавливает account_id модели Recipient.

        :param value: account_id модели Recipient.
        :type value: str
        """
        self.__account_id = str(value)

    @property
    def gateway_id(self):
        """
        Возвращает gateway_id модели Recipient.

        :return: gateway_id модели Recipient.
        :rtype: str
        """
        return self.__gateway_id

    @gateway_id.setter
    def gateway_id(self, value):
        """
        Устанавливает gateway_id модели Recipient.

        :param value: gateway_id модели Recipient.
        :type value: str
        """
        self.__gateway_id = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import ResponsePaymentData


class PaymentDataSbp(ResponsePaymentData):
    """
    Оплата через СБП (Система быстрых платежей ЦБ РФ).
    """  # noqa: E501

    __sbp_operation_id = None
    """Идентификатор операции в СБП (НСПК). Пример: ~`1027088AE4CB48CB81287833347A8777`. Обязательный параметр для платежей в статусе ~`succeeded`. В остальных случаях может отсутствовать. """  # noqa: E501

    __payer_bank_details = None
    """Реквизиты счета, который использовался для оплаты. Обязательный параметр для платежей в статусе ~`succeeded`. В остальных случаях может отсутствовать."""

    def __init__(self, *args, **kwargs):
        super(PaymentDataSbp, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBP:
            self.type = PaymentMethodType.SBP

    @property
    def sbp_operation_id(self):
        """Возвращает sbp_operation_id модели PaymentDataSbp.

        :return: sbp_operation_id модели PaymentDataSbp.
        :rtype: str
        """
        return self.__sbp_operation_id

    @sbp_operation_id.setter
    def sbp_operation_id(self, value):
        """Устанавливает sbp_operation_id модели PaymentDataSbp.

        :param value: sbp_operation_id модели PaymentDataSbp.
        :type value: str
        """
        self.__sbp_operation_id = value

    @property
    def payer_bank_details(self):
        """Возвращает payer_bank_details модели PaymentDataSbp.

        :return: payer_bank_details модели PaymentDataSbp.
        :rtype: SbpPayerBankDetails
        """
        return self.__payer_bank_details

    @payer_bank_details.setter
    def payer_bank_details(self, value):
        """Устанавливает payer_bank_details модели PaymentDataSbp.

        :param value: payer_bank_details модели PaymentDataSbp.
        :type value: SbpPayerBankDetails
        """
        if isinstance(value, dict):
            self.__payer_bank_details = SbpPayerBankDetails(value)
        elif isinstance(value, SbpPayerBankDetails):
            self.__payer_bank_details = value


class SbpPayerBankDetails(BaseObject):
    """Реквизиты счета, который использовался для оплаты.  Обязательный параметр для платежей в статусе ~`succeeded`. В остальных случаях может отсутствовать. """  # noqa: E501

    __bank_id = None
    """Идентификатор банка или платежного сервиса в СБП (НСПК)."""  # noqa: E501

    __bic = None

    @property
    def bank_id(self):
        """Возвращает bank_id модели SbpPayerBankDetails.

        :return: bank_id модели SbpPayerBankDetails.
        :rtype: str
        """
        return self.__bank_id

    @bank_id.setter
    def bank_id(self, value):
        """Устанавливает bank_id модели SbpPayerBankDetails.

        :param value: bank_id модели SbpPayerBankDetails.
        :type value: str
        """
        self.__bank_id = value

    @property
    def bic(self):
        """Возвращает bic модели SbpPayerBankDetails.

        :return: bic модели SbpPayerBankDetails.
        :rtype: str
        """
        return self.__bic

    @bic.setter
    def bic(self, value):
        """Устанавливает bic модели SbpPayerBankDetails.

        :param value: bic модели SbpPayerBankDetails.
        :type value: str
        """
        self.__bic = value



# -*- coding: utf-8 -*-
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class PayoutPersonalData(BaseObject):
    """
    Персональные данные получателя выплаты. Необходимо передавать, если вы делаете выплату с [проверкой получателя](/developers/payouts/scenario-extensions/recipient-check). Только для обычных выплат.
    """  # noqa: E501

    __id = None
    """Идентификатор персональных данных, сохраненных в ЮKassa."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели PayoutPersonalData.

        :return: id модели PayoutPersonalData.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели PayoutPersonalData.

        :param value: id модели PayoutPersonalData.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 50:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `50`")  # noqa: E501
        if value is not None and len(value) < 36:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `36`")  # noqa: E501
        self.__id = value


class PersonalDataType(object):
    """Тип персональных данных — цель, для которой вы будете использовать данные.
    Возможные значение:
    * `sbp_payout_recipient` — [выплаты с проверкой получателя](https://yookassa.ru/developers/payouts/scenario-extensions/recipient-check)(только для выплат через СБП);
    * `payout_statement_recipient` — [выплаты с передачей данных получателя выплаты для выписок из реестра](https://yookassa.ru/developers/payouts/scenario-extensions/recipient-data-send). """  # noqa: E501

    """
    Список допустимых значений
    """
    PAYOUT_STATEMENT_RECIPIENT = "payout_statement_recipient"
    """Выплаты с передачей данных получателя выплаты для выписок из реестра"""
    SBP_PAYOUT_RECIPIENT = "sbp_payout_recipient"
    """Выплаты с проверкой получателя."""


class PersonalDataStatus(object):
    """Статус персональных данных.
    Возможные значения:
     * `waiting_for_operation` — данные сохранены, но не использованы при проведении выплаты;
     * `active` — данные сохранены и использованы при проведении выплаты; данные можно использовать повторно до срока, указанного в параметре `expires_at`;
     * `canceled` — хранение данных отменено, данные удалены, инициатор и причина отмены указаны в объекте cancellation_details (финальный и неизменяемый статус)."""  # noqa: E501

    """
    Список допустимых значений
    """
    WAITING_FOR_OPERATION = "waiting_for_operation"
    """Данные сохранены, но не использованы при проведении выплаты."""
    ACTIVE = "active"
    """Данные сохранены и использованы при проведении выплаты."""
    CANCELED = "canceled"
    """Хранение данных отменено."""



# -*- coding: utf-8 -*-

class PaymentMethodType:
    """
    Константы, представляющие значения payment_method_data. Возможные значения:

    * yookassa.domain.common.PaymentMethodType.YOO_MONEY
    * yookassa.domain.common.PaymentMethodType.BANK_CARD
    * yookassa.domain.common.PaymentMethodType.SBERBANK
    * yookassa.domain.common.PaymentMethodType.CASH
    * yookassa.domain.common.PaymentMethodType.MOBILE_BALANCE
    * yookassa.domain.common.PaymentMethodType.PSB
    * yookassa.domain.common.PaymentMethodType.QIWI
    * yookassa.domain.common.PaymentMethodType.WEBMONEY
    * yookassa.domain.common.PaymentMethodType.ALFABANK
    * yookassa.domain.common.PaymentMethodType.APPLEPAY
    * yookassa.domain.common.PaymentMethodType.GOOGLE_PAY
    * yookassa.domain.common.PaymentMethodType.INSTALMENTS
    * yookassa.domain.common.PaymentMethodType.B2B_SBERBANK
    * yookassa.domain.common.PaymentMethodType.TINKOFF_BANK
    * yookassa.domain.common.PaymentMethodType.WECHAT
    * yookassa.domain.common.PaymentMethodType.SBP
    * yookassa.domain.common.PaymentMethodType.SBER_LOAN
    * yookassa.domain.common.PaymentMethodType.ELECTRONIC_CERTIFICATE
    * yookassa.domain.common.PaymentMethodType.UNKNOWN
    """  # noqa: E501

    """
    Список допустимых значений
    """
    YOO_MONEY = 'yoo_money'
    """Платеж из кошелька ЮMoney"""
    BANK_CARD = 'bank_card'
    """Платеж с произвольной банковской карты"""
    SBERBANK = 'sberbank'
    """Платеж СбербанкОнлайн"""
    CASH = 'cash'
    """Платеж наличными"""
    MOBILE_BALANCE = 'mobile_balance'
    """Платеж с баланса мобильного телефона"""
    PSB = 'psb'
    """ПромсвязьБанк"""
    QIWI = 'qiwi'
    """Платеж из кошелька Qiwi"""
    WEBMONEY = 'webmoney'
    """Платеж из кошелька Webmoney"""
    ALFABANK = 'alfabank'
    """Платеж через Альфа-Клик"""
    APPLEPAY = 'apple_pay'
    """Платеж ApplePay"""
    GOOGLE_PAY = 'google_pay'
    """Платеж Google Pay"""
    INSTALMENTS = 'installments'
    """Заплатить по частям"""
    B2B_SBERBANK = 'b2b_sberbank'
    """Сбербанк Бизнес Онлайн"""
    TINKOFF_BANK = 'tinkoff_bank'
    """T-Pay"""
    WECHAT = 'wechat'
    """Оплата через WeChat"""
    SBP = 'sbp'
    """Оплата через сервис быстрых платежей"""
    SBER_LOAN = 'sber_loan'
    """Прием оплаты с использованием Кредита от СберБанка"""
    ELECTRONIC_CERTIFICATE = 'electronic_certificate'
    """Прием платежей по электронному сертификату, привязанному к карте «Мир»"""
    UNKNOWN = 'unknown'
    """Для неизвестных методов оплаты"""



# -*- coding: utf-8 -*-


class ReceiptType:
    """
    Константы, представляющие значения типа чеков.
    """  # noqa: E501

    PAYMENT = 'payment'
    """Тип чека: приход"""
    REFUND = 'refund'
    """Тип чека: возврат"""


class ReceiptItemAgentType:
    """
    Константы, представляющие значения типа посредника.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    BANKING_PAYMENT_AGENT = 'banking_payment_agent'
    """Банковский платежный агент"""
    BANKING_PAYMENT_SUBAGENT = 'banking_payment_subagent'
    """Банковский платежный субагент"""
    PAYMENT_AGENT = 'payment_agent'
    """Платежный агент"""
    PAYMENT_SUBAGENT = 'payment_subagent'
    """Платежный субагент"""
    ATTORNEY = 'attorney'
    """Поверенный"""
    COMMISSIONER = 'commissioner'
    """Комиссионер"""
    AGENT = 'agent'
    """Агент"""



# -*- coding: utf-8 -*-
import json
from decimal import Decimal


class BaseObject(object):
    """
    Базовый класс генерируемых объектов.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        for dictionary in args:
            for key in dict(dictionary):
                setattr(self, key, dictionary[key])
        for key in kwargs:
            setattr(self, key, kwargs[key])

    def __getitem__(self, item):
        return dict(self)[item]

    def __iter__(self):
        property_names = [prop for prop in dir(self.__class__) if isinstance(getattr(self.__class__, prop), property)]
        properties = dict((value, getattr(self, value)) for value in property_names if getattr(self, value) is not None)
        for prop_name, prop_value in properties.items():
            if isinstance(prop_value, BaseObject):
                yield prop_name, dict(prop_value)
            elif isinstance(prop_value, list):
                list_value = []
                for value in prop_value:
                    if isinstance(value, BaseObject):
                        list_value.append(dict(value))
                    else:
                        list_value.append(value)
                yield prop_name, list_value
            elif isinstance(prop_value, Decimal):
                yield prop_name, str(prop_value)
            else:
                yield prop_name, prop_value

    def json(self):
        return json.dumps(dict(self), default=str, ensure_ascii=False)



# -*- coding: utf-8 -*-
import re
from decimal import Decimal

from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.mark_code_info import MarkCodeInfo
from yookassa.domain.models.receipt_data.mark_quantity import MarkQuantity
from yookassa.domain.models.receipt_data.receipt_item_supplier import ReceiptItemSupplier


class ReceiptItemRequest(BaseObject):
    """
    Объект запроса к API на создание товарной позиции в заказе (для формирования чека).
    """  # noqa: E501

    __description = None
    """Название товара (от 1 до 128 символов). Тег в 54 ФЗ — 1030. """  # noqa: E501

    __amount = None
    """Суммарная стоимость покупаемого товара в копейках/центах."""  # noqa: E501

    __vat_code = None
    """Ставка НДС, число 1-6 (тег в 54 ФЗ — 1199)."""  # noqa: E501

    __quantity = None
    """Количество (тег в 54 ФЗ — 1023)."""  # noqa: E501

    __measure = None
    """Мера количества предмета расчета (тег в 54 ФЗ — 2108)."""  # noqa: E501

    __mark_quantity = None
    """Дробное количество маркированного товара (тег в 54 ФЗ — 1291)."""  # noqa: E501

    __payment_subject = None
    """Признак предмета расчета (тег в 54 ФЗ — 1212)."""  # noqa: E501

    __payment_mode = None
    """Признак способа расчета (тег в 54 ФЗ — 1214)."""  # noqa: E501

    __country_of_origin_code = None
    """Код страны происхождения товара по общероссийскому классификатору стран мира ([OК (MК (ИСО 3166) 004-97) 025-2001](http://docs.cntd.ru/document/842501280)). Тег в 54 ФЗ — 1230. Пример: ~`RU`. <br/>Можно передавать, если используете онлайн-кассу Orange Data, Кит Инвест. """  # noqa: E501

    __customs_declaration_number = None
    """Номер таможенной декларации (от 1 до 32 символов). Тег в 54 ФЗ — 1231. <br/>Можно передавать, если используете онлайн-кассу Orange Data, Кит Инвест. """  # noqa: E501

    __excise = None
    """Сумма акциза товара с учетом копеек (тег в 54 ФЗ — 1229). Десятичное число с точностью до 2 знаков после точки. <br/>Можно передавать, если используете онлайн-кассу Orange Data, Кит Инвест. """  # noqa: E501

    __product_code = None
    """Код товара (тег в 54 ФЗ — 1162) — уникальный номер, который присваивается экземпляру товара при маркировке. <br/>Формат: число в шестнадцатеричном представлении с пробелами. Максимальная длина — 32 байта. Пример: ~`00 00 00 01 00 21 FA 41 00 23 05 41 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 12 00 AB 00`.  Обязательный параметр, если одновременно выполняются эти условия:  * вы используете онлайн-кассу, обновленную до ФФД 1.05; * товар нужно [маркировать](http://docs.cntd.ru/document/902192509). """  # noqa: E501

    __mark_code_info = None
    """Код товара (тег в 54 ФЗ — 1163)."""  # noqa: E501

    __mark_mode = None
    """Режим обработки кода маркировки (тег в 54 ФЗ — 2102).  Обязательный параметр, если одновременно выполняются эти условия:  * вы используете Чеки от ЮKassa или онлайн-кассу Атол Онлайн или BusinessRu, обновленную до ФФД 1.2; * товар нужно [маркировать](http://docs.cntd.ru/document/902192509).  Должен принимать значение равное «0». """  # noqa: E501

    __payment_subject_industry_details = None
    """Отраслевой реквизит предмета расчета (тег в 54 ФЗ — 1260). Можно передавать, если используете Чеки от ЮKassa или онлайн-кассу, обновленную до ФФД 1.2. """  # noqa: E501

    __additional_payment_subject_props = None
    """ Дополнительный реквизит предмета расчета (тег в 54 ФЗ — 1191). Не более 64 символов. <br/>Можно передавать, если вы отправляете данные для формирования чека по сценарию %[Сначала платеж, потом чек](/developers/payment-acceptance/receipts/54fz/other-services/basics#receipt-after-payment) """  # noqa: E501

    __supplier = None
    """Информация о поставщике товара или услуги (тег в 54 ФЗ — 1224)."""  # noqa: E501

    __agent_type = None
    """Тип посредника, реализующего товар или услугу."""  # noqa: E501

    @property
    def description(self):
        """
        Возвращает description модели ReceiptItemRequest.

        :return: description модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели ReceiptItemRequest.

        :param value: description модели ReceiptItemRequest.
        :type value: str
        """
        self.__description = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели ReceiptItemRequest.

        :return: amount модели ReceiptItemRequest.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели ReceiptItemRequest.

        :param value: amount модели ReceiptItemRequest.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def quantity(self):
        """
        Возвращает quantity модели ReceiptItemRequest.

        :return: quantity модели ReceiptItemRequest.
        :rtype: Decimal
        """
        return self.__quantity

    @quantity.setter
    def quantity(self, value):
        """
        Устанавливает quantity модели ReceiptItemRequest.

        :param value: quantity модели ReceiptItemRequest.
        :type value: Decimal
        """
        self.__quantity = Decimal(str(float(value)))

    @property
    def measure(self):
        """
        Возвращает measure модели ReceiptItemRequest.

        :return: measure модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__measure

    @measure.setter
    def measure(self, value):
        """
        Устанавливает measure модели ReceiptItemRequest.

        :param value: measure модели ReceiptItemRequest.
        :type value: str
        """
        self.__measure = value

    @property
    def mark_quantity(self):
        """
        Возвращает mark_quantity модели ReceiptItemRequest.

        :return: mark_quantity модели ReceiptItemRequest.
        :rtype: MarkQuantity
        """
        return self.__mark_quantity

    @mark_quantity.setter
    def mark_quantity(self, value):
        """
        Устанавливает mark_quantity модели ReceiptItemRequest.

        :param value: mark_quantity модели ReceiptItemRequest.
        :type value: MarkQuantity
        """
        if isinstance(value, dict):
            self.__mark_quantity = MarkQuantity(value)
        elif isinstance(value, MarkQuantity):
            self.__mark_quantity = value
        else:
            raise TypeError('Invalid mark_quantity data type in ReceiptItemRequest.mark_quantity')

    @property
    def vat_code(self):
        """
        Возвращает vat_code модели ReceiptItemRequest.

        :return: vat_code модели ReceiptItemRequest.
        :rtype: int
        """
        return self.__vat_code

    @vat_code.setter
    def vat_code(self, value):
        """
        Устанавливает vat_code модели ReceiptItemRequest.

        :param value: vat_code модели ReceiptItemRequest.
        :type value: int
        """
        self.__vat_code = int(value)

    @property
    def payment_subject(self):
        """
        Возвращает payment_subject модели ReceiptItemRequest.

        :return: payment_subject модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__payment_subject

    @payment_subject.setter
    def payment_subject(self, value):
        """
        Устанавливает payment_subject модели ReceiptItemRequest.

        :param value: payment_subject модели ReceiptItemRequest.
        :type value: str
        """
        self.__payment_subject = str(value)

    @property
    def payment_mode(self):
        """
        Возвращает payment_mode модели ReceiptItemRequest.

        :return: payment_mode модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__payment_mode

    @payment_mode.setter
    def payment_mode(self, value):
        """
        Устанавливает payment_mode модели ReceiptItemRequest.

        :param value: payment_mode модели ReceiptItemRequest.
        :type value: str
        """
        self.__payment_mode = str(value)

    @property
    def country_of_origin_code(self):
        """
        Возвращает country_of_origin_code модели ReceiptItemRequest.

        :return: country_of_origin_code модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__country_of_origin_code

    @country_of_origin_code.setter
    def country_of_origin_code(self, value):
        """
        Устанавливает country_of_origin_code модели ReceiptItemRequest.

        :param value: country_of_origin_code модели ReceiptItemRequest.
        :type value: str
        """
        self.__country_of_origin_code = str(value)

    @property
    def customs_declaration_number(self):
        """
        Возвращает customs_declaration_number модели ReceiptItemRequest.

        :return: customs_declaration_number модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__customs_declaration_number

    @customs_declaration_number.setter
    def customs_declaration_number(self, value):
        """
        Устанавливает customs_declaration_number модели ReceiptItemRequest.

        :param value: customs_declaration_number модели ReceiptItemRequest.
        :type value: str
        """
        self.__customs_declaration_number = str(value)

    @property
    def excise(self):
        """
        Возвращает excise модели ReceiptItemRequest.

        :return: excise модели ReceiptItemRequest.
        :rtype: Decimal
        """
        return self.__excise

    @excise.setter
    def excise(self, value):
        """
        Устанавливает excise модели ReceiptItemRequest.

        :param value: excise модели ReceiptItemRequest.
        :type value: Decimal
        """
        self.__excise = Decimal(str(float(value)))

    @property
    def product_code(self):
        """
        Возвращает product_code модели ReceiptItemRequest.

        :return: product_code модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__product_code

    @product_code.setter
    def product_code(self, value):
        """
        Устанавливает product_code модели ReceiptItemRequest.

        :param value: product_code модели ReceiptItemRequest.
        :type value: str
        """
        self.__product_code = str(value)

    @property
    def mark_code_info(self):
        """
        Возвращает mark_code_info модели ReceiptItemRequest.

        :return: mark_code_info модели ReceiptItemRequest.
        :rtype: MarkCodeInfo
        """
        return self.__mark_code_info

    @mark_code_info.setter
    def mark_code_info(self, value):
        """
        Устанавливает mark_code_info модели ReceiptItemRequest.

        :param value: mark_code_info модели ReceiptItemRequest.
        :type value: MarkCodeInfo
        """
        if isinstance(value, dict):
            self.__mark_code_info = MarkCodeInfo(value)
        elif isinstance(value, MarkCodeInfo):
            self.__mark_code_info = value
        else:
            raise TypeError('Invalid mark_code_info data type in ReceiptItemRequest.mark_code_info')

    @property
    def mark_mode(self):
        """
        Возвращает mark_mode модели ReceiptItemRequest.

        :return: mark_mode модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__mark_mode

    @mark_mode.setter
    def mark_mode(self, value):
        """
        Устанавливает mark_mode модели ReceiptItemRequest.

        :param value: mark_mode модели ReceiptItemRequest.
        :type value: str
        """
        if value is not None and not re.search(r'^[0]{1}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `mark_mode`, must be a follow pattern or equal to `/^[0]{1}$/`")  # noqa: E501
        self.__mark_mode = value

    @property
    def payment_subject_industry_details(self):
        """
        Возвращает payment_subject_industry_details модели ReceiptItemRequest.

        :return: payment_subject_industry_details модели ReceiptItemRequest.
        :rtype: list[IndustryDetails]
        """
        return self.__payment_subject_industry_details

    @payment_subject_industry_details.setter
    def payment_subject_industry_details(self, value):
        """
        Устанавливает payment_subject_industry_details модели ReceiptItemRequest.

        :param value: payment_subject_industry_details модели ReceiptItemRequest.
        :type value: list[IndustryDetails]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(IndustryDetails(item))
                elif isinstance(item, IndustryDetails):
                    items.append(item)
                else:
                    raise TypeError('Invalid payment_subject_industry_details data type in ReceiptItemRequest.payment_subject_industry_details')
            self.__payment_subject_industry_details = items
        else:
            raise TypeError('Invalid payment_subject_industry_details value type in ReceiptItem')

    @property
    def additional_payment_subject_props(self):
        """
        Возвращает additional_payment_subject_props модели ReceiptItemRequest.

        :return: additional_payment_subject_props модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__additional_payment_subject_props

    @additional_payment_subject_props.setter
    def additional_payment_subject_props(self, value):
        """
        Устанавливает additional_payment_subject_props модели ReceiptItemRequest.

        :param value: additional_payment_subject_props модели ReceiptItemRequest.
        :type value: str
        """
        if value is not None and len(value) > 64:
            raise ValueError("Invalid value for `additional_payment_subject_props`, length must be less than or equal to `64`")  # noqa: E501
        self.__additional_payment_subject_props = value

    @property
    def supplier(self):
        """
        Возвращает supplier модели ReceiptItemRequest.

        :return: supplier модели ReceiptItemRequest.
        :rtype: ReceiptItemSupplier
        """
        return self.__supplier

    @supplier.setter
    def supplier(self, value):
        """
        Устанавливает supplier модели ReceiptItemRequest.

        :param value: supplier модели ReceiptItemRequest.
        :type value: ReceiptItemSupplier
        """
        if isinstance(value, dict):
            self.__supplier = ReceiptItemSupplier(value)
        elif isinstance(value, ReceiptItemSupplier):
            self.__supplier = value
        else:
            raise TypeError('Invalid supplier value type')

    @property
    def agent_type(self):
        """
        Возвращает agent_type модели ReceiptItemRequest.

        :return: agent_type модели ReceiptItemRequest.
        :rtype: str
        """
        return self.__agent_type

    @agent_type.setter
    def agent_type(self, value):
        """
        Устанавливает agent_type модели ReceiptItemRequest.

        :param value: agent_type модели ReceiptItemRequest.
        :type value: str
        """
        self.__agent_type = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount


class Settlement(BaseObject):
    """
    Информация о совершенных расчетах. 
    """  # noqa: E501

    __type = None
    """Тип расчета."""  # noqa: E501

    __amount = None
    """Сумма расчета."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели Settlement.

        :return: type модели Settlement.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели Settlement.

        :param value: type модели Settlement.
        :type value: str
        """
        self.__type = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели Settlement.

        :return: amount модели Settlement.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели Settlement.

        :param value: amount модели Settlement.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')


class SettlementType(object):
    """
    Тип расчета.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    CASHLESS = 'cashless'
    """Безналичный расчет."""
    PREPAYMENT = 'prepayment'
    """Предоплата (аванс)."""
    POSTPAYMENT = 'postpayment'
    """Постоплата (кредит)."""
    CONSIDERATION = 'consideration'
    """Встречное предоставление."""


class SettlementPayoutType(object):
    """
    Тип операции. Фиксированное значение: `payout` — выплата продавцу. 
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PAYOUT = 'payout'
    """Выплата продавцу"""



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Amount


class IncomeReceiptData(BaseObject):
    """
    Данные для формирования чека в сервисе Мой налог. Необходимо передавать, если вы делаете выплату %[самозанятому](/developers/payouts/scenario-extensions/self-employed). Только для обычных выплат. 
    """  # noqa: E501

    __service_name = None
    """Описание услуги, оказанной получателем выплаты. Не более 50 символов."""  # noqa: E501

    __amount = None
    """Сумма для печати в чеке."""  # noqa: E501

    @property
    def service_name(self):
        """
        Возвращает service_name модели IncomeReceiptData.

        :return: service_name модели IncomeReceiptData.
        :rtype: str
        """
        return self.__service_name

    @service_name.setter
    def service_name(self, value):
        """
        Устанавливает service_name модели IncomeReceiptData.

        :param value: service_name модели IncomeReceiptData.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `service_name`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 50:
            raise ValueError("Invalid value for `service_name`, length must be less than or equal to `50`")  # noqa: E501
        self.__service_name = value

    @property
    def amount(self):
        """
        Возвращает amount модели IncomeReceiptData.

        :return: amount модели IncomeReceiptData.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели IncomeReceiptData.

        :param value: amount модели IncomeReceiptData.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount data type in IncomeReceiptData.amount')



# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.domain.common.base_object import BaseObject
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.common.context import Context
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.common.http_verb import HttpVerb
from yookassa.domain.common.locale import Locale
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.common.receipt_type import ReceiptType, ReceiptItemAgentType
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.common.response_object import ResponseObject
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.common.user_agent import UserAgent, Version
from yookassa.domain.common.security_helper import SecurityHelper
